<?php
/* vim: set expandtab tabstop=4 shiftwidth=4: */
// +----------------------------------------------------------------------+
// | MCMS: a PHP Content Management System for creating accessible sites. |
// | Copyright (C) 2006  Silvio Moioli                                    |
// |                                                                      |
// | This program is free software; you can redistribute it and/or modify |
// | it under the terms of the GNU General Public License as published by |
// | the Free Software Foundation; either version 2 of the License, or    |
// | (at your option) any later version.                                  |
// |                                                                      |
// | This program is distributed in the hope that it will be useful,      |
// | but WITHOUT ANY WARRANTY; without even the implied warranty of       |
// | MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the        |
// | GNU General Public License for more details.                         |
// |                                                                      |
// | You should have received a copy of the GNU General Public License    |
// | along with this program; if not, write to the Free Software          |
// | Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307 |
// +----------------------------------------------------------------------+
// | Authors: Silvio Moioli <silvio at moioli dot net> www.moioli.net     |
// +----------------------------------------------------------------------+
//
//$Id:

/** Carica la classe base di MCMS per l'interfacciamento al Database */
require_once $_SERVER["DOCUMENT_ROOT"]."/admin/lib/model/Engine.php";
/** Carica il componente di PEAR per l'autenticazione degli utenti */
require_once $_SERVER["DOCUMENT_ROOT"]."/admin/include/pear/Auth.php";
/** Carica la pagina con il form per l'immissione della password */
require_once $_SERVER["DOCUMENT_ROOT"]."/admin/lib/view/AdminLogin.php";

/**
 * Gestore dei permessi degli utenti in MCMS. Permette l'aggiunta, la rimozione
 * e la verifica dei permessi di ciascun utente. Inoltre permette il re-login
 * degli utenti.
 *
 * @package MCMS
 * @author Silvio Moioli
 * @version 2
 */
class AuthManager extends PEAR
{
    /** @var Engine l'oggetto per la comunicazione al Database */
    var $engine = null;
    /** @var Auth il componente di PEAR per l'autenticazione degli utenti */
    var $auth = null;
    /** @var Author l'autore correntemente loggato o null */
    var $currentAuthor = null;

    /**
     * Costruttore standard.
     *
     * @param Engine $engine l'oggetto per la comunicazione al DB in uso
     */
    function AuthManager($engine)
    {
//        print "dsn: ".$engine->dataSourceName."<br/>";
        $this->engine=$engine;
        $this->initAuthWithoutLoginScreen();
    }
    
    /**
     * Inizializza (o re-inizializza) Auth per non mostrare schermate di login
     * in caso di mancato riconoscimento dell'autore.
     */
    function initAuthWithoutLoginScreen()
    {
        $this->auth = new Auth("DB", $this->engine->dataSourceName,"",false);
        $this->auth->start();
    }

    /**
     * Inizializza (o re-inizializza) Auth per mostrare la schermata di login
     * relativa all'autore specificato in caso di mancato riconoscimento dello
     * stesso.
     *
     * @param Author $author l'autore da settare
     */
    function initAuthWithLoginScreen($author)
    {
        $this->currentAuthor = $author;
        $currentLoginPage = new AdminLogin($author);  
        $loginFunction = array($currentLoginPage,"display");
        $this->auth = new Auth("DB", $this->engine->dataSourceName, $loginFunction);
        $this->auth->start();
    }
    
    /**
     * Controlla che l'autore sia effettivamente loggato in MCMS.
     *
     * @param Author $author l'autore da controllare
     * @return true se l'autore  autenticato correttamente
     */
    function checkLogin($author)
    {
        $result = true;
        
        $this->initAuthWithoutLoginScreen();
        
        //Un nuovo login  necessario se nessuno lo ha gi fatto...
        if ($this->auth->getAuth() != true) {
            $result = false;
        }       
        //...o se l'autore tenta di fingersi qualcun altro...
        if ($author->getID() != $this->auth->getUsername()) {
            $result = false;
        }
        return $result;
    }
    
    /**
     * Controlla che l'autore sia effettivamente loggato in MCMS, e che
     * abbia i permessi per modificare un certo oggetto.
     *
     * @param Author $author l'autore da controllare
     * @param mixed l'oggetto da modificare
     * @return true se l'autore  autenticato correttamente e pu modificare
     * l'oggetto
     */
    function isEditAllowed($author, $objectToModify)
    {
        $result = true;
        
        $this->initAuthWithoutLoginScreen();
                
        //Valgono innanzitutto le regole viste al metodo precedente
        if ($this->checkLogin($author) == false) {
            $result = false;
        }
        //...o se l'autore non  in realt il fondatore/autore originale
        $tmp = $objectToModify->getAuthor();
        if ($tmp->getID() != $author->getID()) {
            $result = false;
        }
        return $result;
    }
    
    /**
     * Forza l'autore specificato a rifare il login.
     * @param Author $author l'autore
     */
    function reLogin($author)
    {
        $this->auth->logout();
        //Reinizializza Auth
        $this->initAuthWithLoginScreen($author);
    }
    
    /**
     * Rimuove l'autore da quelli che possono accedere a MCMS.
     *
     * @param Author $author l'autore da rimuovere
     */    
    function removeUser($author)
    {
        $this->auth->logout();
        $this->auth->removeUser($author->getID());
    }
    
    /**
     * Aggiunge un nuovo autore tra quelli che possono
     * accedere a MCMS.
     *
     * @param Author $author l'autore da aggiungere
     * @param string $password la sua password
     */    
    function addUser($author, $password)
    {
        $this->initAuthWithoutLoginScreen();
        $this->auth->addUser($author->getID(), $password);
        $this->auth->setAuth($author->getID());
    }
}

?>
