<?php
/* vim: set expandtab tabstop=4 shiftwidth=4: */
// +----------------------------------------------------------------------+
// | MCMS: a PHP Content Management System for creating accessible sites. |
// | Copyright (C) 2006  Silvio Moioli                                    |
// |                                                                      |
// | This program is free software; you can redistribute it and/or modify |
// | it under the terms of the GNU General Public License as published by |
// | the Free Software Foundation; either version 2 of the License, or    |
// | (at your option) any later version.                                  |
// |                                                                      |
// | This program is distributed in the hope that it will be useful,      |
// | but WITHOUT ANY WARRANTY; without even the implied warranty of       |
// | MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the        |
// | GNU General Public License for more details.                         |
// |                                                                      |
// | You should have received a copy of the GNU General Public License    |
// | along with this program; if not, write to the Free Software          |
// | Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307 |
// +----------------------------------------------------------------------+
// | Authors: Silvio Moioli <silvio at moioli dot net> www.moioli.net     |
// +----------------------------------------------------------------------+
//
//$Id:

/** Carica la classe base di MCMS per l'interfacciamento al Database */
require_once $_SERVER["DOCUMENT_ROOT"]."/admin/lib/model/Engine.php";
/** Carica  il componente per l'aggiornamento di View e Model */
require_once $_SERVER["DOCUMENT_ROOT"]."/admin/lib/controller/Committer.php";
/** Carica le pagine della vista Admin */
require_once $_SERVER["DOCUMENT_ROOT"]."/admin/lib/view/alladmin.inc";

/**
 * Gestisce eventi scatenando le opportune azioni su View e Model.
 *
 * @package MCMS
 * @author Silvio Moioli
 * @version 2
 */
class Dispatcher extends PEAR
{
    /** @var Engine l'oggetto per la comunicazione al Database */
    var $engine = null;
    /** @var Compiler il compilatore di interfacce XHTML */
    var $compiler = null;
    /** @var Committer il componente per l'aggiornamento di View e Model */
    var $committer = null;

    //Piccolo hack per evitare un click tra la creazione di un nuovo sito
    //e la sua modifica
    var $newSite = null;
    //Piccolo hack per evitare di far rifare il login a un autore appena registato
    var $newAuthor = null;
    
    /**
     * Costruttore standard.
     *
     * @param Engine $this->engine l'oggetto per la comunicazione al DB in uso
     */
    function Dispatcher($engine, $authManager)
    {
        $this->engine=$engine;
        $this->compiler = new Compiler();
        $this->committer = new Committer($engine, $authManager);
    }
    
    /**
     * Gestisce un evento.
     *
     * @return 
     */
    function dispatch($event)
    {
        $javascript = true;
        if ($event->getParameter("javascript")=="off") {
            $javascript = false;
        }
        if(is_a($event,"ActionEvent")){
            switch ($event->getAction()){
                case "addArticle":
                    $this->committer->addArticle($event->getSite(),
                        $event->getAuthor(),
                        $event->getParameter("contents"),
                        $event->getParameter("title"),
                        $event->getParameter("keywords"),
                        $event->getCategory(),
                        $event->getParameter("description"),
                        $event->getArticles());
                    break;
                case "editArticle":
                    $this->committer->editArticle($event->getSite(),
                        $event->getArticle(),
                        $event->getParameter("contents"),
                        $event->getParameter("title"),
                        $event->getParameter("keywords"),
                        $event->getCategory(),
                        $event->getParameter("description"),
                        $event->getArticles());
                    break;
                case "dropArticle":
                    $this->committer->dropArticle($event->getSite(),
                        $event->getArticle());
                    break;
                case "addAuthor":
                    $this->newAuthor = $this->committer->addAuthor($event->getParameter("name"),
                        $event->getParameter("surname"),
                        $event->getParameter("nick"),
                        $event->getParameter("email"),
                        $event->getParameter("password"));
                    break;
                case "editAuthor":
                    $this->committer->editAuthor($event->getAuthor(),
                        $event->getParameter("name"),
                        $event->getParameter("surname"),
                        $event->getParameter("nick"),
                        $event->getParameter("email"));
                    break;
                case "dropAuthor":
                    $this->committer->dropAuthor($event->getAuthor());
                    break;
                case "addNews":
                    $this->committer->addNews($event->getSite(),
                        $event->getAuthor(),
                        $event->getParameter("contents"),
                        $event->getParameter("title"),
                        $event->getParameter("keywords"),
                        $event->getParameter("source"),
                        $event->getArticles());
                    break;
                case "editNews":
                    $this->committer->editNews($event->getSite(),
                        $event->getNews(),
                        $event->getParameter("contents"),
                        $event->getParameter("title"),
                        $event->getParameter("keywords"),
                        $event->getParameter("source"),
                        $event->getArticles());
                    break;
                case "dropNews":
                    $this->committer->dropNews($event->getSite(),
                        $event->getNews());
                    break;
                case "addCategory":
                    $this->committer->addCategory($event->getSite(),
                        $event->getParameter("name"),
                        $event->getParameter("description"));
                    break;
                case "editCategory":
                    $this->committer->editCategory($event->getSite(),
                        $event->getCategory(),
                        $event->getParameter("name"),
                        $event->getParameter("description"));
                    break;
                case "dropCategory":
                    $this->committer->dropCategory($event->getSite(),
                        $event->getCategory());
                    break;
                case "addSite":
                    $this->newSite = $this->committer->addSite($event->getAuthor(),
                        $event->getParameter("name"),
                        $event->getParameter("slogan"),
                        $event->getParameter("keywords"));
                    break;
                case "dropSite":
                    $this->committer->dropSite($event->getSite());
                    break;
                case "editComponents":
                    $this->committer->editComponents($event->getSite(),
                        $event->getComponents());
                    break;
                case "editHomepage":
                    $this->committer->editHomepage($event->getSite(),
                        $event->getParameter("contents"),
                        $event->getParameter("slogan"),
                        $event->getParameter("keywords"));
                    break;
                case null:
                    break;
                default:
                    print "do.php: unrecognized action ".$event->getParameter("action")." <br />";
                    break;
            }
        }
        elseif(is_a($event,"GoToEvent")){
            switch ($event->getPage()) {
                case "AdminIndex":
                    $this->compiler->display(new AdminIndex($this->engine));
                    break;
                case "AdminAddAuthor":
                    $page = new AdminAddAuthor();
                    if ($event->getParameter("defaults") == "true") {
                        $page->setDefaultName($event->getParameter("name"));
                        $page->setDefaultSurname($event->getParameter("surname"));
                        $page->setDefaultNick($event->getParameter("nick"));
                        $page->setDefaultEmail($event->getParameter("email"));
                    }
                    $this->compiler->display($page);
                    break;
                case "AdminMain":
                    $page = null;
                    //Se sono al primo login dopo la registrazione...
                    if ($this->newAuthor != null) {
                        $page = new AdminMain($this->newAuthor);
                    }
                    else {
                        //Se è un login ordinario
                        $page = new AdminMain($event->getAuthor());
                    }
                    $this->compiler->display($page);
                    break;
                case "AdminManageSite":
                    $page = null;
                    //sito appena creato
                    if ($this->newSite != null) {
                        $page = new AdminManageSite($event->getAuthor(), $this->newSite);
                    }
                    else {
                        //sito già creato
                        $page = new AdminManageSite($event->getAuthor(), $event->getSite());
                    }
                    $this->compiler->display($page);
                    break;        
                    
                case "AdminAddSite":
                    $this->compiler->display(new AdminAddSite($event->getAuthor()));
                    break;
                case "AdminEditAuthor":
                    $author = $event->getAuthor();
                    $page = new AdminEditAuthor($author);
                    if ($event->getParameter("defaults") == "true") {
                        $page->setDefaultName($event->getParameter("name"));
                        $page->setDefaultSurname($event->getParameter("surname"));
                        $page->setDefaultNickname($event->getParameter("nick"));
                        $page->setDefaultEmail($event->getParameter("email"));
                    }
                    $this->compiler->display($page);
                    break;
                case "AdminDropAuthor":
                    $this->compiler->display(new AdminDropAuthor($event->getAuthor()));
                    break;
                    
                case "AdminDropSite":
                    $this->compiler->display(new AdminDropSite($event->getAuthor(),
                        $event->getSite()));
                    break;
                case "AdminEditNews":
                    $page = null;
                    $news = null;
                    if ($event->getParameter("mode") == "new") {
                        //Nuova notizia
                        $page = new AdminEditNews($event->getAuthor(), $event->getSite(),
                                null, "new", $javascript);
                    }
                    elseif ($event->getParameter("mode") == "edit") {
                        //Modifica notizia
                        $news = $event->getNews();
                        $page = new AdminEditNews($event->getAuthor(), $event->getSite(),
                                $news, "edit", $javascript);
                    }
                    //Se sono specificati valori di default per la pagina, settali
                    if ($event->getParameter("defaults") == "true") {
                        $page->setDefaultTitle($event->getParameter("title"));
                        $page->setDefaultKeywords($event->getParameter("keywords"));
                        $page->setDefaultSource($event->getParameter("source"));
                        $page->setDefaultContents($event->getParameter("contents"));
                        $page->setDefaultCorrelatedArticles($event->getArticles());
                    }
                    $this->compiler->display($page);
                    break;
                case "AdminListNews":
                    $page = new AdminListNews($event->getAuthor(), $event->getSite());
                    $this->compiler->display($page);
                    break;
                case "AdminEditArticle":
                    //Controlla i permessi e inizializza la pagina
                    $page = null;
                    $article = null;
                    if ($event->getParameter("mode") == "new") {
                        $page = new AdminEditArticle($event->getAuthor(),$event->getSite(),
                            $article,"new",$javascript);
                    }
                    elseif ($event->getParameter("mode") == "edit") {
                        $article = $event->getArticle();
                        $page = new AdminEditArticle($event->getAuthor(),$event->getSite(),
                            $article,"edit",$javascript);
                    }
                    //Se sono specificati valori di default per la pagina, settali
                    if ($event->getParameter("defaults") == "true") {
                        $page->setDefaultTitle($event->getParameter("title"));
                        $page->setDefaultKeywords($event->getParameter("keywords"));
                        $page->setDefaultDescription($event->getParameter("description"));
                        $page->setDefaultContents($event->getParameter("contents"));
                        $page->setDefaultCorrelatedArticles($event->getArticles());
                        $page->setDefaultCategory($event->getCategory());
                    }
                    //Visualizza la pagina
                    $this->compiler->display($page);
                    break;
                case "AdminListArticles":
                    $page = new AdminListArticles($event->getAuthor(), $event->getSite());
                    $this->compiler->display($page);
                    break;
                case "AdminListCategories":
                    $this->compiler->display(new AdminListCategories($event->getAuthor(),
                        $event->getSite()));
                    break;
                case "AdminEditCategory":
                    //Modifica sezione
                    $page = null;
                    $category = null;
                    if ($event->getParameter("mode") == "new") {
                        $page = new AdminEditCategory($event->getAuthor(), $event->getSite(),
                            null,"new");
                    }
                    elseif ($event->getParameter("mode") == "edit") {
                        $category = $event->getCategory();
                        $page = new AdminEditCategory($event->getAuthor(), $event->getSite(),
                            $category,"edit");
                    }
                    //Se sono specificati valori di default per la pagina, settali
                    if ($event->getParameter("defaults") == "true") {
                        $page->setDefaultName($event->getParameter("name"));
                        $page->setDefaultDescription($event->getParameter("description"));
                    }
                    //Visualizza la pagina
                    $this->compiler->display($page);
                    break;
                case "AdminEditHomepage":
                    $site = $event->getSite();
                    $dataDispatcheromepage = $site->getHomepage();
                    $page = new AdminEditHomepage($event->getAuthor(),
                        $site,
                        $javascript,
                        $event->getParameter("slogan"),
                        $event->getParameter("keywords"),
                        $event->getParameter("contents"));
                    if ($event->getParameter("defaults") == "true") {
                        $page->setDefaultSlogan($event->getParameter("slogan"));
                        $page->setDefaultKeywords($event->getParameter("keywords"));
                        $page->setDefaultContents($event->getParameter("contents"));
                    }
                    $this->compiler->display($page);
                    break;
                case "AdminDropNews":
                    $this->compiler->display(new AdminDropNews($event->getAuthor(), $event->getSite(),
                        $event->getNews()));
                    break;
                case "AdminDropArticle":
                    $page = new AdminDropArticle($event->getSite(), $event->getArticle(),
                        $event->getAuthor());
                    $this->compiler->display($page);
                    break;
                case "AdminDropCategory":
                    $this->compiler->display(new AdminDropCategory($event->getAuthor(),
                        $event->getSite(), $event->getCategory()));
                    break;
                default:
                    print "NO GOTO page specified! ";
                    break;
                }
        }
    }
}
?>
