<?php
/* vim: set expandtab tabstop=4 shiftwidth=4: */
// +----------------------------------------------------------------------+
// | MCMS: a PHP Content Management System for creating accessible sites. |
// | Copyright (C) 2006  Silvio Moioli                                    |
// |                                                                      |
// | This program is free software; you can redistribute it and/or modify |
// | it under the terms of the GNU General Public License as published by |
// | the Free Software Foundation; either version 2 of the License, or    |
// | (at your option) any later version.                                  |
// |                                                                      |
// | This program is distributed in the hope that it will be useful,      |
// | but WITHOUT ANY WARRANTY; without even the implied warranty of       |
// | MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the        |
// | GNU General Public License for more details.                         |
// |                                                                      |
// | You should have received a copy of the GNU General Public License    |
// | along with this program; if not, write to the Free Software          |
// | Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307 |
// +----------------------------------------------------------------------+
// | Authors: Silvio Moioli <silvio at moioli dot net> www.moioli.net     |
// +----------------------------------------------------------------------+
//
//$Id:

/** Carica la classe base di MCMS per l'interfacciamento al Database */
require_once $_SERVER["DOCUMENT_ROOT"]."/admin/lib/model/Engine.php";

/**
 * Evento di MCMS.
 * Un Event modella una possibile richiesta dell'utente con tutti i parametri
 * ad essa associati (POST e GET).
 *
 * @package MCMS
 * @author Silvio Moioli
 * @version 2
 */
class Event extends PEAR
{
    /** @var Engine l'oggetto per la comunicazione al Database */
    var $engine = null;
    /** @var array i parametri di questo evento */
    var $parameters = array();
    
    /**
     * Costruttore standard.
     *
     * @param array $post i parametri POST della richiesta
     * @param array $get i parametri GET della richiesta
     */
    /*abstract*/ function Event($engine, $post, $get)
    {
        $this->engine=$engine;         
        $httpParams=array_merge($post,$get);
        foreach ($httpParams as $key => $value) {
            if ($key == "contents"){
                $this->parameters[$key] = $this->formatInputXml($value);
            }
            else{
                $this->parameters[$key] = $this->formatInputText($value);
            }
        }
    }
    
    /**
     * Ritorna un parametro generico (se esiste).
     * 
     * @return string il parametro o null
     */
    function getParameter($key){
        if (array_key_exists($key, $this->parameters)){
            return $this->parameters[$key];
        }
        else{
            return null;
        }
    }
    
    /**
     * Ritorna tutti i parametri.
     * 
     * @return array i parametri
     */
    function getParameters(){
        return $this->parameters;
    }
    
    /** 
     * Se tra i parametri c'è un ID di autore, ritorna l'oggetto
     * corrispondente.
     *
     * @return l'oggetto Author o null
     */
    function getAuthor(){
        $result = null;
        if (array_key_exists("authorID", $this->parameters)){
            $id = $this->parameters["authorID"];
            if ($id!= null){
                $result = new Author($id, $this->engine);
            }
        }
        return $result;
    }
    
    /** 
     * Se tra i parametri c'è un ID di articolo, ritorna l'oggetto
     * corrispondente.
     *
     * @return l'oggetto Article o null
     */
    function getArticle(){
        $result = null;
        if (array_key_exists("articleID", $this->parameters)){
            $id = $this->parameters["articleID"];
            if ($id!= null){
                $result = new Article($id, $this->engine);
            }
        }
        return $result;
    }
    
    /** 
     * Se tra i parametri c'è un ID di notizia, ritorna l'oggetto
     * corrispondente.
     *
     * @return l'oggetto News o null
     */
    function getNews(){
        $result = null;
        if (array_key_exists("newsID", $this->parameters)){
            $id = $this->parameters["newsID"];
            if ($id!= null){
                $result = new News($id, $this->engine);
            }
        }
        return $result;
    }
    
    /** 
     * Se tra i parametri c'è un ID di sito, ritorna l'oggetto
     * corrispondente.
     *
     * @return l'oggetto Site o null
     */
    function getSite(){
        $result = null;
        if (array_key_exists("siteID", $this->parameters)){
            $id = $this->parameters["siteID"];
            if ($id!= null){
                $result = new Site($id, $this->engine);
            }
        }
        return $result;
    }

    /** 
     * Se tra i parametri c'è un ID di sezione, ritorna l'oggetto
     * corrispondente.
     *
     * @return l'oggetto Category o null
     */
    function getCategory(){
        $result = null;
        if (array_key_exists("categoryID", $this->parameters)){
            $id = $this->parameters["categoryID"];
            if ($id!= null){
                $result = new Category($id, $this->engine);
            }
        }
        return $result;
    }
    
    /** 
     * Se tra i parametri ci sono più ID di articolo, ritorna 
     * gli oggetti corrispondenti.
     *
     * @return un array di Article
     */
    function getArticles(){
        $result = array();
        for ($i=0; $i<count($this->parameters); $i++) {
            if (array_key_exists("article$i", $this->parameters)){
                $id = $this->parameters["article".$i."ID"];
                if ($id!= null){
                    $result []= new Article($id, $this->engine);
                }
            }
        }
        return $result;
    }
    
    /** 
     * Se tra i parametri ci sono più ID di componente, ritorna 
     * gli oggetti corrispondenti.
     *
     * @return un array di Components
     */
    function getComponents(){
        $result = array();
        $components = $this->engine->getComponents();
        $componentNames = array();
        foreach($components as $i){
            $componentName = get_class($i);
            require_once $_SERVER["DOCUMENT_ROOT"]."/admin/lib/plugins/$componentName.php";
            if (array_key_exists("component$componentName", $this->parameters) &&
                $this->parameters["component$componentName"] == "on") {
                $result[] = $i;
            }
        }
        return $result;
    }
     
    //Metodi privati
    /**
     * Formatta (applica il quoting) a stringhe potenzialmente non sicure
     * che devono essere trattate come testo semplice.
     *
     * @param string $string la stringa da preparare
     * @return la stringa formattata
     */
    function formatInputText($string){
        return htmlspecialchars(stripslashes($string), ENT_QUOTES);
    }

    /**
     * Formatta (applica il quoting) a stringhe potenzialmente non sicure
     * che devono essere trattate come XML.
     *
     * @param string $string la stringa da preparare
     * @return la stringa formattata
     */
    function formatInputXml($string){
        $result = stripslashes($string);
        //Rimuovi il codice JavaScript
        $result = preg_replace("@<script[^>]*?>.*?</script>@si", "", $result);
        return $result;
    } 
}