<?php
/* vim: set expandtab tabstop=4 shiftwidth=4: */
// +----------------------------------------------------------------------+
// | MCMS: a PHP Content Management System for creating accessible sites. |
// | Copyright (C) 2006  Silvio Moioli                                    |
// |                                                                      |
// | This program is free software; you can redistribute it and/or modify |
// | it under the terms of the GNU General Public License as published by |
// | the Free Software Foundation; either version 2 of the License, or    |
// | (at your option) any later version.                                  |
// |                                                                      |
// | This program is distributed in the hope that it will be useful,      |
// | but WITHOUT ANY WARRANTY; without even the implied warranty of       |
// | MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the        |
// | GNU General Public License for more details.                         |
// |                                                                      |
// | You should have received a copy of the GNU General Public License    |
// | along with this program; if not, write to the Free Software          |
// | Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307 |
// +----------------------------------------------------------------------+
// | Authors: Silvio Moioli <silvio at moioli dot net> www.moioli.net     |
// +----------------------------------------------------------------------+
//
//$Id:

/** Carica la classe base di MCMS per l'interfacciamento al Database */
require_once $_SERVER["DOCUMENT_ROOT"]."/admin/lib/model/Engine.php";
/** Carica il gestore dei permessi degli utenti in MCMS */
require_once $_SERVER["DOCUMENT_ROOT"]."/admin/lib/controller/AuthManager.php";
/** Carica le pagine della vista Admin */
require_once $_SERVER["DOCUMENT_ROOT"]."/admin/lib/view/alladmin.inc";

/**
 * Verifica la correttezza di un evento.
 *
 * @package MCMS
 * @author Silvio Moioli
 * @version 2
 */
class Validator extends PEAR
{
    /** @var Engine l'oggetto per la comunicazione al Database */
    var $engine = null;
    /** @var AuthManager l'oggetto per la gestione dell'autenticazione degli utenti. */
    var $authManager = null;
    
    /**
     * Costruttore standard.
     *
     * @param Engine $engine l'oggetto per la comunicazione al DB in uso
     */
    function Validator($engine, $authManager)
    {
        $this->engine=$engine;
        $this->authManager = $authManager;
        $this->compiler = new Compiler();
    }
    
    /**
     * Controlla la validità del comando passato.
     *
     * @param Event $event l'evento da controllare
     * @param mixed $result un oggetto Author se l'utente non
     * è autenticato correttamente o un oggetto AdminError se qualche
     * altro errore si è verificato.
     * @return true se l'evento è valido
     */
    function validate($event, &$result)
    {
        $author=$event->getAuthor();
        if(is_a($event,"ActionEvent")){
            switch ($event->getAction()){
                case "addArticle":
                    if ($this->authManager->checkLogin($author)==false) {
                        $result = $author;
                        return false;
                    }
                    
                    $contents = $event->getParameter("contents");
                    $title = $event->getParameter("title");
                    
                    if ($contents == ""){
                        $params = $event->getParameters();
                        $params["defaults"] = "true";
                        $result = new AdminError("non hai specificato contenuti per l'articolo.",
                            "AdminEditArticle",$params);
                        return false;
                    }
                    if ($title == ""){
                        $params = $event->getParameters();
                        $params["defaults"] = "true";
                        $result = new AdminError("non hai specificato un titolo per l'articolo.",
                            "AdminEditArticle", $params);
                        return false;
                    }
                    
                    return true;
                    break;
                case "editArticle":
                    $article = $event->getArticle();
                    if ($this->authManager->isEditAllowed($author,$article)==false) {
                        $result = $author;
                        return false;
                    }   
                    
                    $contents = $event->getParameter("contents");
                    $title = $event->getParameter("title");
                    
                    if ($contents == ""){
                        $params = $event->getParameters();
                        $params["defaults"] = "true";
                        $result = new AdminError("non hai specificato contenuti per l'articolo.",
                            "AdminEditArticle",$params);
                        return false;
                    }
                    if ($title == ""){
                        $params = $event->getParameters();
                        $params["defaults"] = "true";
                        $result = new AdminError("non hai specificato un titolo per l'articolo.",
                            "AdminEditArticle", $params);
                        return false;
                    }
                    
                    return true;
                    break;
                case "dropArticle":
                    $article = $event->getArticle();
                    if ($this->authManager->isEditAllowed($author,$article)==false) {
                        $result = $author;
                        return false;
                    }   
                    return true;
                    break;
                case "addAuthor":
                    //Possono sempre iscriversi nuovi autori...
                    $name = $event->getParameter("name");
                    $surname = $event->getParameter("surname");
                    $email = $event->getParameter("email");
                    $password = $event->getParameter("password");
            
                    if ($name == ""){
                        $params = $event->getParameters();
                        $params["defaults"] = "true";
                        $result = new AdminError("non hai specificato il nome.",
                            "AdminAddAuthor", $params);
                        return false;
                    }
                    if ($surname == ""){
                        $params = $event->getParameters();
                        $params["defaults"] = "true";
                        $result = new AdminError("non hai specificato il cognome.",
                            "AdminAddAuthor", $params);
                        return false;
                    }
                    if ($password == "" || $password=="abc"){
                        $params = $event->getParameters();
                        $params["defaults"] = "true";
                        $result = new AdminError("non hai specificato la password.",
                            "AdminAddAuthor", $params);
                        return false;
                    }
                    if (preg_match("/^[^@]+@[^\.@]+\.[^\.]+$/i",$email)==0){
                        $params = $event->getParameters();
                        $params["defaults"] = "true";
                        $result = new AdminError("l'indirizzo email inserito non &egrave; corretto.",
                            "AdminAddAuthor", $params);
                        return false;
                    }
                    
                    return true;
                    break;
                case "editAuthor":
                    if ($this->authManager->checkLogin($author)==false) {
                        $result = $author;
                        return false;
                    }
                    $name = $event->getParameter("name");
                    $surname = $event->getParameter("surname");
                    $email = $event->getParameter("email");
                    
                    if ($name == ""){
                        $params = $event->getParameters();
                        $params["defaults"] = "true";
                        $result = new AdminError("non hai specificato il nome.",
                            "AdminEditAuthor", $params);
                        return false;
                    }
                    if ($surname == ""){
                        $params = $event->getParameters();
                        $params["defaults"] = "true";
                        $result = new AdminError("non hai specificato il cognome.",
                            "AdminEditAuthor", $params);
                        return false;
                    }
              
                    if (preg_match("/^[^@]+@[^\.@]+\.[^\.]+$/i",$email)==0){
                        $params = $event->getParameters();
                        $params["defaults"] = "true";
                        $result = new AdminError("l'indirizzo email inserito non &egrave; corretto.",
                            "AdminEditAuthor", $params);
                        return false;
                    }
            
                    return true;
                    break;
                case "dropAuthor":
                    if ($this->authManager->checkLogin($author)==false) {
                        $result = $author;
                        return false;
                    }
                    return true;
                    break;
                case "addNews":
                    if ($this->authManager->checkLogin($author)==false) {
                        $result = $author;
                        return false;
                    }
                    
                    $contents =  $event->getParameter("contents");
                    $title = $event->getParameter("title");
                    
                    if ($contents == ""){
                        $params = $event->getParameters();
                        $params["defaults"] = "true";
                        $result = new AdminError("non hai specificato contenuti per la notizia.",
                            "AdminEditNews",$params);
                        return false;
                    }
                    if ($title == ""){
                        $params = $event->getParameters();
                        $params["defaults"] = "true";
                        $result = new AdminError("non hai specificato un titolo per la notizia.",
                            "AdminEditNews", $params);
                        return false;
                    }
            
                    return true;
                    break;
                case "editNews":
                    $news = $event->getNews();
                    
                    if ($this->authManager->isEditAllowed($author,$news)==false) {
                        $result = $author;
                        return false;
                    }  
                    
                    $contents =  $event->getParameter("contents");
                    $title = $event->getParameter("title");
                    
                    if ($contents == ""){
                        $params = $event->getParameters();
                        $params["defaults"] = "true";
                        $result = new AdminError("non hai specificato contenuti per la notizia.",
                            "AdminEditNews",$params);
                        return false;
                    }
                    
                    if ($title == ""){
                        $params = $event->getParameters();
                        $params["defaults"] = "true";
                        $result = new AdminError("non hai specificato un titolo per la notizia.",
                            "AdminEditNews", $params);
                        return false;
                    }
            
                    return true;
                    break;
                case "dropNews":
                    $news = $event->getNews();
                    
                    if ($this->authManager->isEditAllowed($author,$news)==false) {
                        $result = $author;
                        return false;
                    }  
    
                    return true;
                    break;
                case "addCategory":
                    $site = $event->getSite();
                    if ($this->authManager->isEditAllowed($author,$site)==false) {
                        $result = $author;
                        return false;
                    }
                    $name = $event->getParameter("name");
            
                    if ($name == ""){
                        $params = $event->getParameters();
                        $params["defaults"] = "true";
                        $result = new AdminError("non hai specificato un nome per la sezione.",
                            "AdminEditCategory", $params);
                        return false;
                    }
            
                    return true;
                    break;
                case "editCategory":
                    $site = $event->getSite();
                    if ($this->authManager->isEditAllowed($author,$site)==false) {
                        $result = $author;
                        return false;
                    }
                                    
                    $name = $event->getParameter("name");
            
                    if ($name == ""){
                        $params = $event->getParameters();
                        $params["defaults"] = "true";
                        $result = new AdminError("non hai specificato un nome per la sezione.",
                            "AdminEditCategory", $params);
                        return false;
                    }
                    
                    return true;
                    break;
                case "dropCategory":
                    $site = $event->getSite();
                    if ($this->authManager->isEditAllowed($author,$site)==false) {
                        $result = $author;
                        return false;
                    }
                    if ($site->getCategoriesCount()<=1){
                        $params = $event->getParameters();
                        $result = new AdminError("non puoi cancellare l'ultima sezione del sito!",
                            "AdminListCategories", $params);
                        return false;
                    }
                    return true;
                    break;
                case "addSite":
                    if ($this->authManager->checkLogin($author)==false) {
                        $result = $author;
                        return false;
                    }
                    $url = $event->getParameter("name");
                    if (preg_match('#^http://www(\.[a-zA-Z0-9]+){2,6}$#',$url)==0){
                        $params = $event->getParameters();
                        $params["defaults"] = "true";
                        $result = new AdminError("l'URL inserito non &egrave; corretto.",
                            "AdminAddSite", $params);
                        return false;
                    }
                    return true;
                    break;
                case "dropSite":
                    $site = $event->getSite();
                    if ($this->authManager->isEditAllowed($author,$site)==false) {
                        $result = $author;
                        return false;
                    }
                    return true;
                    break;
                case "editComponents":
                    $site = $event->getSite();
                    if ($this->authManager->isEditAllowed($author,$site)==false) {
                        $result = $author;
                        return false;
                    }
                    return true;
                    break;
                case "editHomepage":
                    $site = $event->getSite();
                    if ($this->authManager->isEditAllowed($author,$site)==false) {
                        $result = $author;
                        return false;
                    }
                    $contents=$event->getParameter("contents");
                    $slogan=$event->getParameter("slogan");
                    
                    if ($slogan == ""){
                        $params = $event->getParameters();
                        $params["defaults"] = "true";
                        $result = new AdminError("non hai specificato uno slogan per l'homepage.",
                            "AdminEditHomepage", $params);
                        return false;
                    }
                    if ($contents == ""){
                        $params = $event->getParameters();
                        $params["defaults"] = "true";
                        $result = new AdminError("non hai specificato contenuti per l'homepage.",
                            "AdminEditHomepage", $params);
                        return false;
                    }
                    return true;
                    break;
                case null:
                    return true;
                    break;
                default:
                    print "Validator: unrecognized action ".$event->getAction()." <br />";
                    break;
            }
        }
        elseif(is_a($event,"GoToEvent")){
            switch ($event->getParameter("goTo")) {
                case "AdminIndex":
                case "AdminAddAuthor":
                    return true;
                    break;
                case "AdminListNews":
                case "AdminListArticles":
                case "AdminManageSite":
                case "AdminAddSite":
                case "AdminEditAuthor":
                case "AdminDropAuthor":
                    $result = $author;
                    return $this->checkLogin($author);
                    break;
                case "AdminDropSite":
                case "AdminListCategories":
                case "AdminEditHomepage":
                    $result = $author;
                    return $this->isEditAllowed($author, $event->getSite());
                    break;
                case "AdminDropNews":
                    $result = $author;
                    return $this->isEditAllowed($author, $event->getNews());
                    break;
                case "AdminDropArticle":
                    $result = $author;
                    return $this->isEditAllowed($author, $event->getArticle());
                    break;
                case "AdminDropCategory":
                    $site = $event->getSite();
                    if ($site->getCategoriesCount()<=1){
                        $params = $event->getParameters();
                        $result = new AdminError("non puoi cancellare l'ultima sezione del sito!",
                            "AdminListCategories", $params);
                        return false;
                    }
                    $result = $author;
                    return $this->isEditAllowed($author, $event->getCategory());
                    break;
                case "AdminMain":
                    //Se sono al primo login dopo la registrazione...
                    if ($event->getParameter("action")=="addAuthor") {
                        return true;
                    }
                    else {//login ordinario
                        $result = $author;
                        return $this->checkLogin($author);
                    }
                    break;
                case "AdminEditNews":
                    if ($event->getParameter("mode") == "new") {
                        $result = $author;
                        return $this->checkLogin($author);
                    }
                    elseif ($event->getParameter("mode") == "edit") {
                        $result = $author;
                        return $this->isEditAllowed($author, $event->getNews());
                    }
                    break;
                case "AdminEditArticle":
                    //Controlla i permessi e inizializza la pagina
                    if ($event->getParameter("mode") == "new") {
                        $result = $author;
                        return $this->checkLogin($author);
                    }
                    elseif ($event->getParameter("mode") == "edit") {
                        $result = $author;
                        return $this->isEditAllowed($author, $event->getArticle());
                    }
                    break;
                case "AdminEditCategory":
                    //Modifica sezione
                    if ($event->getParameter("mode") == "new") {
                        $result = $author;
                        return $this->checkLogin($author);
                    }
                    elseif ($event->getParameter("mode") == "edit") {
                        $result = $author;
                        return $this->isEditAllowed($author, $event->getCategory());
                    }
                    break;
                default:
                    print "NO GOTO page specified! ";
                    break;
            }
        }
    }
    
    function checkLogin($author)
    {
       return $this->authManager->checkLogin($author);
    }
        
    function isEditAllowed($author, $object)
    {
        return $this->authManager->isEditAllowed($author,$object);
    }
}

?>
