<?php
/* vim: set expandtab tabstop=4 shiftwidth=4: */
// +----------------------------------------------------------------------+
// | MCMS: a PHP Content Management System for creating accessible sites. |
// | Copyright (C) 2006  Silvio Moioli                                    |
// |                                                                      |
// | This program is free software; you can redistribute it and/or modify |
// | it under the terms of the GNU General Public License as published by |
// | the Free Software Foundation; either version 2 of the License, or    |
// | (at your option) any later version.                                  |
// |                                                                      |
// | This program is distributed in the hope that it will be useful,      |
// | but WITHOUT ANY WARRANTY; without even the implied warranty of       |
// | MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the        |
// | GNU General Public License for more details.                         |
// |                                                                      |
// | You should have received a copy of the GNU General Public License    |
// | along with this program; if not, write to the Free Software          |
// | Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307 |
// +----------------------------------------------------------------------+
// | Authors: Silvio Moioli <silvio at moioli dot net> www.moioli.net     |
// +----------------------------------------------------------------------+
//
//$Id:
/**
 * Interfaccia per la gestione delle notizie del sito.
 *
 * @package  MCMS
 * @version  2
 * @author   Silvio Moioli <silvio at moioli dot net>
 *
 */
 
/** Carica la classe base di MCMS per l'interfacciamento al Database */
require_once $_SERVER["DOCUMENT_ROOT"]."/admin/lib/model/Engine.php";
/**
 * Carica la classe per le pagine (Page)
 */
require_once $_SERVER["DOCUMENT_ROOT"]."/admin/lib/model/Page.php";
 
/**
 * Interfaccia per la gestione delle notizie del sito.
 *
 * Permette di utilizzare il database in modo trasparente: creare oggetti
 * di questa classe e operare sugli attributi tramite gli appositi metodi
 * modificher automaticamente il database sottostante.
 * 
 * @package  MCMS
 * @version  2
 * @author   Silvio Moioli <silvio at moioli dot net>
 *
 */
class News extends Page
{
    //Attributi ereditati: $ID e $engine

    //Costruttori   
    /**
     * Costruttore di lettura
     *
     * Costruttore "di lettura" (costruisce una notizia da un record del
     * database gi esistente).
     * Nota: non pu essere creata una nuova notizia da qui, ma solo dal Factory
     * Method nella classe Site.
     * Per i costruttori "di scrittura", quindi, vedere la classe Site
     * nel file Site.php.
     *
     * @param int $ID l'ID del database sottostante
     * @param Engine $engine un motore per interagire con il database 
     * sottostante
     * @return mixed la notizia se la costruzione  andata a buon fine, altrimenti
     * un PEAR_Error
     * @see Engine
     */
    function News($ID, $engine)
    {
        $this->Page($ID, $engine);
    }
    
    //Metodi
    /**
     * Getter per il campo Fonte dalla tabella Notizia.
     * 
     * Ritorna una stringa con l'URL della principale fonte da cui  tratta
     * questa notizia. Permette di utilizzare il fontebase in modo 
     * trasparente ( come se si usassero normali attributi di una classe).
     *
     * @return mixed una stringa con l'URL se l'operazione  andata a buon fine,
     * NULL se la notizia non ha fonte (interna al sito), altrimenti
     * un DB_ERROR in caso di errore
     */
     function getSource()
     {
        $thisEngine = $this->getEngine();
        $thisDB = $thisEngine->getDB();
        $thisID = $thisDB->escapeSimple($this->getID());
        $res = $thisDB->getOne("SELECT `url fonte notizia` FROM `notizie`".
                               "WHERE `id pagina` = '$thisID' LIMIT 1;");
        
        #$thisDB->disconnect();
        return $res;
     }
    
    /**
     * Setter per il campo Fonte dalla tabella Notizia.
     * 
     * Cambia l'oggetto corrispondente alla fonte di ultima modifica di 
     * questa notizia. Permette di utilizzare il fontebase in modo 
     * trasparente ( come se si usassero normali attributi di una classe).
     *
     * @param string $source l'URL della fonte primaria di questa notizia o
     * NULL.
     * @return mixed true se l'operazione  andata a buon fine, altrimenti
     * un DB_ERROR
     */
     function setSource($source)
     {
        $thisEngine = $this->getEngine();
        $thisDB = $thisEngine->getDB();
        $thisID = $thisDB->escapeSimple($this->getID());
        $source = $thisDB->escapeSimple($thisDB->escapeSimple($source));
        $thisDB->query("UPDATE `notizie` SET `url fonte notizia`='$source'".
                       "WHERE `id pagina` = '$thisID';");
        
        #$thisDB->disconnect();
        return true;
     }
     
    /**
     * Getter per gli articoli correlati a questa notizia.
     * 
     * Ritorna un array contenente gli articoli correlati a questa notizia.
     *
     * @return mixed un array di Article se l'operazione  andata a 
     * buon fine o un DB_ERROR in caso di errore
     * @see Article
     */
     function getCorrelatedArticles()
     {
        $thisEngine = $this->getEngine();
        $thisDB = $thisEngine->getDB();
        $newsID = $thisDB->escapeSimple($this->getID());
        
        $sql = "SELECT `id articolo` FROM `articoli correlati notizia` WHERE".
               "`id notizia` ='$newsID';";
        $articleIDs = $thisDB->getCol($sql);

        #$thisDB->disconnect();
                
        //Creo l'array degli oggetti a partire dagli IDs
        $articles = array();
        foreach ($articleIDs as $i) {
            $articles[] = new Article($i, $thisEngine);
        }

        return $articles;
     }
     
    /**
     * Ritorna il numero degli articoli correlati a questa notizia.
     * 
     *
     * @return mixed un int se l'operazione  andata a 
     * buon fine o un DB_ERROR in caso di errore
     * @see Article
     */
     function getCorrelatedArticlesCount()
     {
        $thisEngine = $this->getEngine();
        $thisDB = $thisEngine->getDB();
        $newsID = $thisDB->escapeSimple($this->getID());
        
        $sql = "SELECT COUNT(`id articolo`) FROM `articoli correlati notizia` WHERE".
               "`id notizia` ='$newsID';";
        $result = $thisDB->getCol($sql);

        #$thisDB->disconnect();
        return $result;
     }
     
    /**
     * Setter per gli articoli correlati a questa notizia.
     * 
     * Cambia gli articoli correlati a questa notizia con un insieme di altri.
     *
     * @param array $articles i nuovi articoli correlati
     * @return mixed true se l'operazione  andata a buon fine o un DB_ERROR
     * in caso di errore
     * @see Article
     */
     function setCorrelatedArticles($articles)
     {
         $this->dropCorrelatedArticles();
         foreach ($articles as $i){
             $this->addCorrelatedArticle($i);
         }
         
         return true;
     }
    
    /**
     * Aggiunge un nuovo articolo correlato.
     * 
     * L'articolo specificato viene catalogato come correlato a questa notizia.
     *
     * @param Article $article l'articolo da aggiungere
     * @return mixed true se l'operazione  andata a buon fine o un 
     * DB_ERROR in caso di errore
     * @see Article
     */
     function addCorrelatedArticle($article)
     {
        $thisEngine = $this->getEngine();
        $thisDB = $thisEngine->getDB();
        $articleID = $thisDB->escapeSimple($article->getID());
        $pageID = $thisDB->escapeSimple($this->getID());
        $sql = "INSERT INTO `articoli correlati notizia` (`id notizia`,".
               "`id articolo` ) VALUES ( '$pageID', '$articleID' );";
        $thisDB->query($sql);
        

        #$thisDB->disconnect();
        return true;
     }
     
    /**
     * Rimuove un articolo correlato.
     * 
     * Rimuove la correlazione fra questa notizia e l'articolo passato.
     *
     * @param Article $article l'articolo da rimuovere
     * @return mixed true se l'operazione  andata a buon fine o un 
     * DB_ERROR in caso di errore
     * @see Article
     */
     function dropCorrelatedArticle($article)
     {
        $thisEngine = $this->getEngine();
        $thisDB = $thisEngine->getDB();
        $articleID = $thisDB->escapeSimple($article->getID());
        $pageID = $thisDB->escapeSimple($this->getID());

        $sql = "DELETE FROM `articoli correlati notizia` WHERE".
               "(`id notizia`='$pageID' AND `id articolo`='$articleID');";
        $thisDB->query($sql);

        #$thisDB->disconnect();
        return true;
     }
     
    /**
     * Rimuove tutti gli articoli correlati.
     * 
     * Rimuove tutti gli articoli correlati a questa notizia.
     *
     * @return mixed true se l'operazione  andata a buon fine o un 
     * DB_ERROR in caso di errore
     * @see Article
     */
     function dropCorrelatedArticles()
     {
        $thisEngine = $this->getEngine();
        $thisDB = $thisEngine->getDB();
        $newsID = $thisDB->escapeSimple($this->getID());
        
        $sql = "DELETE FROM `articoli correlati notizia` WHERE".
               "`id notizia`='$newsID'";
        $thisDB->query($sql);

        #$thisDB->disconnect();
        return true;
     }
}
?>
