<?php
/* vim: set expandtab tabstop=4 shiftwidth=4: */
// +----------------------------------------------------------------------+
// | MCMS: a PHP Content Management System for creating accessible sites. |
// | Copyright (C) 2006  Silvio Moioli                                    |
// |                                                                      |
// | This program is free software; you can redistribute it and/or modify |
// | it under the terms of the GNU General Public License as published by |
// | the Free Software Foundation; either version 2 of the License, or    |
// | (at your option) any later version.                                  |
// |                                                                      |
// | This program is distributed in the hope that it will be useful,      |
// | but WITHOUT ANY WARRANTY; without even the implied warranty of       |
// | MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the        |
// | GNU General Public License for more details.                         |
// |                                                                      |
// | You should have received a copy of the GNU General Public License    |
// | along with this program; if not, write to the Free Software          |
// | Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307 |
// +----------------------------------------------------------------------+
// | Authors: Silvio Moioli <silvio at moioli dot net> www.moioli.net     |
// +----------------------------------------------------------------------+
//
//$Id:
/**
 * Classe per l'aggiunta di un feed RSS 2 al sito.
 *
 * @package  MCMS
 * @version  2
 * @author   Silvio Moioli <silvio at moioli dot net>
 */

/** Carica la classe base di MCMS per l'interfacciamento al Database */
require_once $_SERVER["DOCUMENT_ROOT"]."/admin/lib/model/Engine.php";

/**
 *  Classe per l'aggiunta di un feed RSS 2 al sito.
 *
 *
 * @package  MCMS
 * @version  2
 * @author   Silvio Moioli <silvio at moioli dot net>
 */
class rss extends Component
{
    /**
     * Scritto solo per la concatenazione dei costruttori.
     *
     */
    function rss()
    {
        $this->Component();
    }

    /**
     * Ritorna il nome di questo componente.
     *
     * @return string il nome del componente
     */
    function getName()
    {
        return "Feed RSS";
    }

    /**
     *
     * Questo componente non ha bisogno di inizializzazione,
     * perci questo metodo  vuoto.
     *
     * @param Engine $engine il motore di MCMS
     */
    function init($engine)
    {
    }

    /**
     *
     * Aggiunge la voce di menu per la mappa del sito (a tutte le
     * pagine).
     *
     * @param string $contents i contenuti della pagina da modificare
     * @param array $menuEntries il menu della pagina
     * @param string $title il titolo della pagina da modificare
     * @param Site $site il sito corrente
     */
    function applyComponent(&$contents, &$menuEntries, &$title,
        &$description, $site)
    {
        $siteID = $site->getID();
        $menuEntries [] = "<p><a type=\"application/rss+xml\"".
        " href=\"/feed.rss\">Feed RSS</a> per restare sempre aggiornato!</p>";
    }
    
    /**
     * Salva il feed RSS 2.0 del sito
     *
     * @param Site $site il sito corrente
     * @param Compiler $compiler l'oggetto per il salvataggio dei file
     * @see Component
     */
    function saveFiles($site, $compiler)
    {
        $siteName = $site->getURL();
        $result = "<?xml version=\"1.0\" encoding='ISO-8859-1'?>
            <rdf:RDF 
            xmlns:rdf=\"http://www.w3.org/1999/02/22-rdf-syntax-ns#\"
            xmlns=\"http://purl.org/rss/1.0/\"
            xmlns:dc=\"http://purl.org/dc/elements/1.1/\"
            >
            <channel rdf:about=\"http://www.moioli.net/feed.rss\">
            <title>moioli.net</title>
            <link>$siteName</link>
            <description>Sito di Silvio Moioli</description>
            <items>
            <rdf:Seq>
                <rdf:li resource=\"$siteName/#notizia1\"/>
                <rdf:li resource=\"$siteName/#notizia2\"/>
                <rdf:li resource=\"$siteName/#notizia3\"/>
                <rdf:li resource=\"$siteName/#notizia4\"/>
                <rdf:li resource=\"$siteName/#notizia5\"/>
            </rdf:Seq>
            </items>
            </channel>";
        $news = $site->getNews();
        $newscount = 0;
        foreach ($news as $i) {
            //Massimo 5 notizie sul feed
            if ($newscount >= 5) {
                break;
            }
            $newscount++;
            $newsTitle = strip_tags($i->getTitle());
            $content = strip_tags($i->getContents());
            $content = str_replace($content,"&","&amp;");
            $date = $i->getDate();
            $result .= "<item rdf:about=\"$siteName/#notizia$newscount\">
                <title>$newsTitle</title>
                <link>$siteName/#$newscount</link>
                <description>$content</description>
                <dc:date>$date</dc:date>
                </item>";
        }
        $result .="</rdf:RDF>";
        $compiler->fileSave("feed.rss", $result, false);
    }
}
?>
