<?php
/* vim: set expandtab tabstop=4 shiftwidth=4: */
// +----------------------------------------------------------------------+
// | MCMS: a PHP Content Management System for creating accessible sites. |
// | Copyright (C) 2006  Silvio Moioli                                    |
// |                                                                      |
// | This program is free software; you can redistribute it and/or modify |
// | it under the terms of the GNU General Public License as published by |
// | the Free Software Foundation; either version 2 of the License, or    |
// | (at your option) any later version.                                  |
// |                                                                      |
// | This program is distributed in the hope that it will be useful,      |
// | but WITHOUT ANY WARRANTY; without even the implied warranty of       |
// | MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the        |
// | GNU General Public License for more details.                         |
// |                                                                      |
// | You should have received a copy of the GNU General Public License    |
// | along with this program; if not, write to the Free Software          |
// | Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307 |
// +----------------------------------------------------------------------+
// | Authors: Silvio Moioli <silvio at moioli dot net> www.moioli.net     |
// +----------------------------------------------------------------------+
//
//$Id:

/** Importa la classe di base per l"interfaccia utente (autore) */
require_once $_SERVER["DOCUMENT_ROOT"]."/admin/lib/view/AdminPage.php";
/** Importa la libreria per semplificare l"aggiunta di tag XML */
require_once $_SERVER["DOCUMENT_ROOT"]."/admin/lib/view/Tagger.php";

/**
 * Rappresenta la pagina di aggiunta di un nuovo sito (vengono richiesti l'URL,
 * le parole chiave, ecc.)
 * 
 * @package  MCMS
 * @version  2
 * @author   Silvio Moioli <silvio at moioli dot net>
 */
class AdminAddSite extends AdminPage
{
    /** @var Author l'autore che accede a questa pagina */
    var $author = null;
    
    /** @var string nome proposto all'utente per questo sito */
    var $defaultName="http://www.mionuovosito.it";
    /** @var string motto proposto all'utente per questo sito */
    var $defaultSlogan="Eccomi qui!";
    /** @var string parole chiave proposte all'utente per questo sito */
    var $defaultKeywords="";
        
    /**
     * Costruttore standard
     *
     * @param Author $author l'autore del sito da aggiungere
     * @see AdminPage
     */
    function AdminAddSite($author)
    {
        parent::AdminPage();
        $this->author=$author;
    }
    
    /**
     * Cambia il nome proposto all'utente per questo sito
     *
     * @param string $defaultName il nuovo nome
     */
    function setDefaultName($defaultName)
    {
        $this->defaultName = $defaultName;
    }
    
    /**
     * Cambia il motto proposto all'utente per questo sito
     *
     * @param string $defaultTitle il nuovo motto
     */
    function setDefaultSlogan($defaultSlogan)
    {
        $this->defaultSlogan = $defaultSlogan;
    }
    
    /**
     * Cambia le parole chiave proposte all'utente per questo sito
     *
     * @param string $defaultKeywords le nuove parole chiave
     */
    function setDefaultKeywords($defaultKeywords)
    {
        $this->defaultKeywords = $defaultKeywords;
    }
    
        /**
     * Ritorna il titolo (in XHTML) di questa pagina.
     *
     * @return string una stringa XHTML rappresentante il titolo della pagina
     * @see Compilable
     */
    function getTitle()
    {
        $authorID = $this->author->getID();
        $title = a("do.php?goTo=AdminMain&amp;authorID=$authorID",
        "Il Progettista")." > Aggiungi sito";
        return $title;
    }
    
    /**
     * Ritorna un array di stringhe XHTML relative al menu (barra di navigazione)
     * di questa pagina.
     *
     * @return array vettore di stringhe XHTML rappresentante il menu della pagina
     * @see Compilable
     */
    function getMenuEntries()
    {
        $menuEntries = array(p(a("do.php?goTo=AdminIndex",
        "Annulla e torna alla pagina principale del Progettista")));
        return $menuEntries;
    }
    
    /**
     * Ritorna il contenuto (XHTML) del corpo di questa pagina.
     *
     * @return string la stringa XHTML rappresentante il corpo della pagina
     * @see Compilable
     */
    function getContents()
    {
        $authorID = $this->author->getID();
        
        $formContents = h1("Incominciamo dal nome...").
        p("Cosa sarebbe un buon sito senza un nome? Bene, il Progettista consiglia
        di partire dal nome per creare il tuo sito. Come saprai, i nomi dei siti
        Internet si chiamano URL, e il tuo sito non fa eccezione. Inserisci qui
        l&#039;URL attraverso cui i visitatori accederanno al tuo sito (se non ne
        hai uno, potresti provarne uno gratuito registrandolo su ".
        a("http://www.dot.tk/","www.dot.tk").br().input("text","name",$this->defaultName).br().
        "Se non sai cos&#039;&egrave; un URL, o non sai cosa sia un dominio e 
        come dovrebbe essere usato, dovresti imparare qualche nozione base su 
        Internet. Un buon posto dove iniziare: ".a("http://www.html.it/",
        "HTML.it")).
        h1("...poi un motto...").
        p("Un&#039;altra buona idea &egrave;dare uno slogan al tuo sito. Se &egrave;
        brillante i visitatori se lo ricorderanno!".br().
        "Il Progettista consiglia: qualcosa di breve (per esempio Clarence: a
        wwworld apart)".br().
        input("text","slogan",$this->defaultSlogan)).
        h1("...e le parole chiave!").
        p("Per finire, indica per favore una lista di parole chiave per il tuo
        sito. Dovrebbero essere delle parole che aiutino gli utenti Internet nelle
        loro ricerche, e dovrebbero essere inerenti ai contenuti del tuo sito.".
        br()."Il Progettista raccomanda: per favore ".b("elenca le parole
        separandole con una virgola!").br().
        input("text", "keywords",$this->defaultKeywords)).
        p("Quando hai finito, clicca il bottone qui sotto:".br().
        submit());
        
        $contents = form("do.php?goTo=AdminManageSite&amp;".
        "action=addSite&amp;authorID=$authorID","POST", $formContents);
        
        return $contents;
    }
}
?>
