<?php
/* vim: set expandtab tabstop=4 shiftwidth=4: */
// +----------------------------------------------------------------------+
// | MCMS: a PHP Content Management System for creating accessible sites. |
// | Copyright (C) 2006  Silvio Moioli                                    |
// |                                                                      |
// | This program is free software; you can redistribute it and/or modify |
// | it under the terms of the GNU General Public License as published by |
// | the Free Software Foundation; either version 2 of the License, or    |
// | (at your option) any later version.                                  |
// |                                                                      |
// | This program is distributed in the hope that it will be useful,      |
// | but WITHOUT ANY WARRANTY; without even the implied warranty of       |
// | MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the        |
// | GNU General Public License for more details.                         |
// |                                                                      |
// | You should have received a copy of the GNU General Public License    |
// | along with this program; if not, write to the Free Software          |
// | Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307 |
// +----------------------------------------------------------------------+
// | Authors: Silvio Moioli <silvio at moioli dot net> www.moioli.net     |
// +----------------------------------------------------------------------+
//
//$Id:

/** Importa la classe di base per l"interfaccia utente (autore) */
require_once $_SERVER["DOCUMENT_ROOT"]."/admin/lib/view/AdminPage.php";
/** Importa la libreria per semplificare l"aggiunta di tag XML */
require_once $_SERVER["DOCUMENT_ROOT"]."/admin/lib/view/Tagger.php";

/**
 * Chiede una conferma per la cancellazione di un autore o presenta una
 * notifica qualora l'autore stesso non sia al momento cancellabile.
 * 
 * @package  MCMS
 * @version  2
 * @author   Silvio Moioli <silvio at moioli dot net>
 */
class AdminDropAuthor extends AdminPage
{
    /** @var Author l'autore da cancellare */
    var $author = null;
    
    /**
     * Costruttore di default
     *
     * @param Engine l'oggetto per la comunicazione al Database
     * @param Author l'autore da cancellare
     * @see AdminPage
     */
    function AdminDropAuthor($author)
    {
        parent::AdminPage();
        $this->author=$author;
    }
    
    /**
     * Ritorna il titolo (in XHTML) di questa pagina.
     *
     * @return string una stringa XHTML rappresentante il titolo della pagina
     * @see Compilable
     */
    function getTitle()
    {
        $authorID = $this->author->getID();
        
        $title = a("do.php?goTo=AdminMain&amp;authorID=$authorID",
        "Il Progettista")." > Cancella ".$this->author->getName();
        
        return $title;
    }
    
    /**
     * Ritorna un array di stringhe XHTML relative al menu (barra di navigazione)
     * di questa pagina.
     *
     * @return array vettore di stringhe XHTML rappresentante il menu della pagina
     * @see Compilable
     */
    function getMenuEntries()
    {
        $authorID = $this->author->getID();
    
        $menuEntries = array(p(a("do.php?goTo=AdminMain&amp;".
        "authorID=$authorID","Torna alla pagina principale del Progettista")));
        
        return $menuEntries;
    }
    
    /**
     * Ritorna il contenuto (XHTML) del corpo di questa pagina.
     *
     * @return string la stringa XHTML rappresentante il corpo della pagina
     * @see Compilable
     */
    function getContents()
    {
        $engine = $this->author->getEngine();
        $authorID = $this->author->getID();
        $contents = "";
        
        if ($engine->isAuthorDroppable($this->author)) {
            $contents = h1("Il Progettista sta per cancellare 
                l&#039;autore!").p("Sei proprio sicuro?".br().
                form("do.php?goTo=AdminIndex&amp;action=dropAuthor&amp;",
                    "POST",
                    input("hidden","authorID",$authorID).
                    submit("S&igrave;, cancella l'autore!")
                ).br().
                h2(a("do.php?goTo=AdminMain&amp;authorID=$authorID",
                "No, torna alla pagina precedente")));
        }
        else {
            $contents = h1("Attenzione! Il Progettista non pu&ograve;
            cancellare un autore se egli/ella ha scritto articoli, fondato siti
            o scritto notizie!").
            p("Se vuoi essere cancellato come autore, devi prima assicurarti che
            tutti gli articoli e notizie che hai scritto e che tutti i siti
            che hai fondato siano cancellati!").
            h2(a("do.php?goTo=AdminMain&amp;authorID=$authorID",
            "Torna alla pagina precedente"));
        }
        
        return $contents;
    }
}

?>
