<?php
/* vim: set expandtab tabstop=4 shiftwidth=4: */
// +----------------------------------------------------------------------+
// | MCMS: a PHP Content Management System for creating accessible sites. |
// | Copyright (C) 2006  Silvio Moioli                                    |
// |                                                                      |
// | This program is free software; you can redistribute it and/or modify |
// | it under the terms of the GNU General Public License as published by |
// | the Free Software Foundation; either version 2 of the License, or    |
// | (at your option) any later version.                                  |
// |                                                                      |
// | This program is distributed in the hope that it will be useful,      |
// | but WITHOUT ANY WARRANTY; without even the implied warranty of       |
// | MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the        |
// | GNU General Public License for more details.                         |
// |                                                                      |
// | You should have received a copy of the GNU General Public License    |
// | along with this program; if not, write to the Free Software          |
// | Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307 |
// +----------------------------------------------------------------------+
// | Authors: Silvio Moioli <silvio at moioli dot net> www.moioli.net     |
// +----------------------------------------------------------------------+
//
//$Id:

/** Importa la classe di base per l"interfaccia utente (autore) */
require_once $_SERVER["DOCUMENT_ROOT"]."/admin/lib/view/AdminPage.php";
/** Importa la libreria per semplificare l"aggiunta di tag XML */
require_once $_SERVER["DOCUMENT_ROOT"]."/admin/lib/view/Tagger.php";

/**
 * Rappresenta la pagina di rimozione di una notizia. Viene richiesta una conferma
 * da parte dell'utente.
 * 
 * @package  MCMS
 * @version  2
 * @author   Silvio Moioli <silvio at moioli dot net>
 */
class AdminDropNews extends AdminPage
{
    /** @var Author l'autore che accede a questa pagina */
    var $author = null;
    /** @var Site il sito a cui la notizia da cancellare appartiene */
    var $site = null;
    /** @var News la notizia da cancellare */
    var $news = null;
    
    /**
     * Costruttore di default
     *
     * @param Author $author l'autore che accede a questa pagina
     * @param Site il sito a cui la notizia da cancellare appartiene
     * @param News $news la notizia da cancellare
     * @see AdminPage
     */
    function AdminDropNews($author, $site, $news)
    {
        parent::AdminPage();
        $this->author=$author;
        $this->site=$site;
        $this->news=$news;
    }
    
    /**
     * Ritorna il titolo (in XHTML) di questa pagina.
     *
     * @return string una stringa XHTML rappresentante il titolo della pagina
     * @see Compilable
     */
    function getTitle()
    {
        $authorID = $this->author->getID();
        $siteID = $this->site->getID();
        
        $title = a("do.php?goTo=AdminMain&amp;authorID=$authorID",
            "Il Progettista")." > ".
            a("do.php?goTo=AdminManageSite&amp;authorID=$authorID&amp;".
            "siteID=$siteID",$this->site->getShortURL())." > ".
            a("do.php?goTo=AdminListNews&amp;authorID=$authorID&amp;siteID=$siteID",
            "Notizie")." > Eliminazione di ".$this->news->getTitle();
        
        return $title;
    }
    
    /**
     * Ritorna un array di stringhe XHTML relative al menu (barra di navigazione)
     * di questa pagina.
     *
     * @return array vettore di stringhe XHTML rappresentante il menu della pagina
     * @see Compilable
     */
    function getMenuEntries()
    {
        $authorID = $this->author->getID();
        $siteID = $this->site->getID();
    
        $menuEntries = array(p(a("do.php?goTo=AdminManageSite&amp;".
            "siteID=$siteID&amp;authorID=$authorID",
            "Annulla e torna alla gestione del sito").br().
            a("do.php?goTo=AdminListNews?siteID=$siteID&amp;authorID=$authorID",
            "Annulla e torna alla gestione delle notizie")));
        
        return $menuEntries;
    }
    
    /**
     * Ritorna il contenuto (XHTML) del corpo di questa pagina.
     *
     * @return string la stringa XHTML rappresentante il corpo della pagina
     * @see Compilable
     */
    function getContents()
    {
        $authorID = $this->author->getID();
        $siteID = $this->site->getID();
        $newsTitle = $this->news->getTitle();
        $newsID = $this->news->getID();
        
        $contents = h1("Attenzione! La notizia dal titolo: \"$newsTitle\"
        sta per essere cancellata!").p("Sei proprio sicuro?".br().
            form("do.php?goTo=AdminListNews&amp;action=dropNews&amp;".
            "authorID=$authorID&amp;siteID=$siteID","POST",
                input("hidden", "newsID", $newsID).
                submit("S&igrave;, cancella la notizia!").br().
            a("do.php?goTo=AdminListNews&amp;siteID=$siteID&amp;authorID=$authorID",
            "No, annulla e torna alla pagina precedente")));
        
        return $contents;
    }
}
?>
