<?php
/* vim: set expandtab tabstop=4 shiftwidth=4: */
// +----------------------------------------------------------------------+
// | MCMS: a PHP Content Management System for creating accessible sites. |
// | Copyright (C) 2006  Silvio Moioli                                    |
// |                                                                      |
// | This program is free software; you can redistribute it and/or modify |
// | it under the terms of the GNU General Public License as published by |
// | the Free Software Foundation; either version 2 of the License, or    |
// | (at your option) any later version.                                  |
// |                                                                      |
// | This program is distributed in the hope that it will be useful,      |
// | but WITHOUT ANY WARRANTY; without even the implied warranty of       |
// | MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the        |
// | GNU General Public License for more details.                         |
// |                                                                      |
// | You should have received a copy of the GNU General Public License    |
// | along with this program; if not, write to the Free Software          |
// | Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307 |
// +----------------------------------------------------------------------+
// | Authors: Silvio Moioli <silvio at moioli dot net> www.moioli.net     |
// +----------------------------------------------------------------------+
//
//$Id:

/** Importa la classe di base per l"interfaccia utente (autore) */
require_once $_SERVER["DOCUMENT_ROOT"]."/admin/lib/view/AdminPage.php";
/** Importa la libreria per semplificare l"aggiunta di tag XML */
require_once $_SERVER["DOCUMENT_ROOT"]."/admin/lib/view/Tagger.php";

/**
 * Chiede una conferma per la cancellazione di un autore.
 * 
 * @package  MCMS
 * @version  2
 * @author   Silvio Moioli <silvio at moioli dot net>
 */
class AdminDropSite extends AdminPage
{
    /** @var Author l'autore che accede a questa pagina */
    var $author = null;
    /** @var Site il sito da cancellare */
    var $site = null;
    
    /**
     * Costruttore di default
     *
     * @param Author $author l'autore che accede a questa pagina
     * @param Site $site il sito da cancellare
     * @see AdminPage
     */
    function AdminDropSite($author, $site)
    {
        parent::AdminPage();
        $this->author=$author;
        $this->site=$site;
    }
    
    /**
     * Ritorna il titolo (in XHTML) di questa pagina.
     *
     * @return string una stringa XHTML rappresentante il titolo della pagina
     * @see Compilable
     */
    function getTitle()
    {
        $authorID = $this->author->getID();
        $siteID = $this->site->getID();
	$siteName = $this->site->getShortURL();
        
        $title = a("do.php?goTo=AdminMain&amp;authorID=$authorID",
        "Il Progettista")." > ".
        a("do.php?goTo=AdminManageSite&amp;authorID=$authorID&amp;siteID=$siteID",
            $siteName)." > Eliminazione sito";
        
        return $title;
    }
    
    /**
     * Ritorna un array di stringhe XHTML relative al menu (barra di navigazione)
     * di questa pagina.
     *
     * @return array vettore di stringhe XHTML rappresentante il menu della pagina
     * @see Compilable
     */
    function getMenuEntries()
    {
        $menuEntries = array(p(a("do.php?goTo=AdminIndex",
        "Annulla e torna alla pagina principale del Progettista")));
        
        return $menuEntries;
    }
    
    /**
     * Ritorna il contenuto (XHTML) del corpo di questa pagina.
     *
     * @return string la stringa XHTML rappresentante il corpo della pagina
     * @see Compilable
     */
    function getContents()
    {
        $authorID = $this->author->getID();
        $siteID = $this->site->getID();
        $siteName = $this->site->getShortURL();
        
        $contents = h1("Attenzione! Il sito $siteName sta per essere 
        cancellato!").
        p("Sei proprio sicuro?".br().
        form("do.php?goTo=AdminMain&amp;action=dropSite&amp;authorID=$authorID",
            "POST",
            input("hidden","siteID",$siteID).
            submit("S&igrave;, cancella il sito!")
        ).br().
        a("do.php?goTo=AdminMain&amp;authorID=$authorID","No, annulla e
        torna alla pagina precedente"));
        
        return $contents;
    }
}
?>
