<?php
/* vim: set expandtab tabstop=4 shiftwidth=4: */
// +----------------------------------------------------------------------+
// | MCMS: a PHP Content Management System for creating accessible sites. |
// | Copyright (C) 2006  Silvio Moioli                                    |
// |                                                                      |
// | This program is free software; you can redistribute it and/or modify |
// | it under the terms of the GNU General Public License as published by |
// | the Free Software Foundation; either version 2 of the License, or    |
// | (at your option) any later version.                                  |
// |                                                                      |
// | This program is distributed in the hope that it will be useful,      |
// | but WITHOUT ANY WARRANTY; without even the implied warranty of       |
// | MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the        |
// | GNU General Public License for more details.                         |
// |                                                                      |
// | You should have received a copy of the GNU General Public License    |
// | along with this program; if not, write to the Free Software          |
// | Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307 |
// +----------------------------------------------------------------------+
// | Authors: Silvio Moioli <silvio at moioli dot net> www.moioli.net     |
// +----------------------------------------------------------------------+
//
//$Id:

/** Importa la classe di base per l"interfaccia utente (autore) */
require_once $_SERVER["DOCUMENT_ROOT"]."/admin/lib/view/AdminPage.php";
/** Importa la libreria per semplificare l"aggiunta di tag XML */
require_once $_SERVER["DOCUMENT_ROOT"]."/admin/lib/view/Tagger.php";

/**
 * Rappresenta la pagina di aggiunta/modifica di un articolo.
 * Presenta una finestra per l'input dell'XHTML.
 * 
 * @package  MCMS
 * @version  2
 * @author   Silvio Moioli <silvio at moioli dot net>
 */
class AdminEditArticle extends AdminPage
{
    /** @var Author l'autore che accede a questa pagina */
    var $author = null;
    /** @var Site il sito a cui appartiene l'articolo da modificare o aggiungere */
    var $site = null;
    /** @var Article l'articolo da modificare, null se  un nuovo articolo */
    var $article = null;
    /** @var string "new" se si aggiunge un nuovo articolo "edit" altrimenti */
    var $mode = "new";
    /** @var bool true se Javascript  in uso per la modifica dell'XHTML */
    var $javascript = true;
    
    /** @var string titolo proposto all'utente per questo articolo */
    var $defaultTitle = "Nuovo articolo";
    /** @var string parole chiave proposte all'utente per questo articolo */
    var $defaultKeywords = "parole chiave";
    /** @var string descrizione proposta all'utente per questo articolo */
    var $defaultDescription = "descrizione";
    /** @var string contenuti (XHTML) proposti all'utente per questo articolo */
    var $defaultContents = "Inserisci i tuoi contenuti <b>qui</b>.";
    /** @var array articoli correlati proposti all'utente per questo articolo */
    var $defaultCorrelatedArticles = array();
    /** @var Category sezione a cui l'articolo appartiene */
    var $defaultCategory = null;
    
    /**
     * Costruttore standard.
     *
     * @see AdminPage
     * @param Author $author l'autore del nuovo articolo o dell'articolo
     * da modificare
     * @param Site $site il sito a cui il nuovo articolo o l'articolo da
     * modificare appartiene
     * @param Article $article l'articolo da modificare o null 
     * @param string $mode "new" o "edit" a seconda che si voglia creare
     * un nuovo articolo o modificarne uno esistente 
     * @param bool $javascript indica la possibilit di usare il JavaScript
     * per l'editor XHTML
     */
    function AdminEditArticle($author, $site, $article, $mode, $javascript) {
        parent::AdminPage();
        $this->author=$author;    
        $this->site=$site;
        $this->article=$article;
        $this->mode=$mode;
        $this->javascript=$javascript;
        
        $categories = $this->site->getCategories();
        $this->defaultCategory = $categories[0];
        if ($mode == "edit") {
            $this->defaultTitle = $article->getTitle();
            $this->defaultKeywords = $article->getKeywords();
            $this->defaultDescription = $article->getDescription();
            $this->defaultContents = $article->getContents();
            $this->defaultCorrelatedArticles = $article->getCorrelatedArticles();
            $this->defaultCategory = $article->getCategory();
        }
    }
    
    /**
     * Cambia il titolo proposto all'utente per questo articolo
     *
     * @param string $defaultTitle il nuovo titolo
     */
    function setDefaultTitle($defaultTitle){
        $this->defaultTitle = $defaultTitle;
    }
    
    /**
     * Cambia le parole chiave proposte all'utente per questo articolo
     *
     * @param string $defaultKeywords le nuove parole chiave
     */
    function setDefaultKeywords($defaultKeywords){
        $this->defaultKeywords = $defaultKeywords;
    }
    
    /**
     * Cambia la descrizione proposta all'utente per questo articolo
     *
     * @param string $defaultDescription la nuova descrizione
     */
    function setDefaultDescription($defaultDescription){
        $this->defaultDescription = $defaultDescription;
    }
    
    /**
     * Cambia i contenuti (XHTML) proposti all'utente per questo articolo
     *
     * @param string $defaultContents i nuovi contenuti
     */
    function setDefaultContents($defaultContents){
        $this->defaultContents = $defaultContents;
    }
    
    /**
     * Cambia gli articoli correlati proposti all'utente per questo articolo
     *
     * @param array $defaultCorrelatedArticles i nuovi articoli correlati
     */
    function setDefaultCorrelatedArticles($defaultCorrelatedArticles){
        $this->defaultCorrelatedArticles = $defaultCorrelatedArticles;
    }

    /**
     * Cambia la sezione a cui l'articolo appartiene
     *
     * @param array $defaultCategory la nuova sezione
     */
    function setDefaultCategory($defaultCategory){
        $this->defaultCategory = $defaultCategory;
    }
    
    /**
     * Ritorna il titolo (in XHTML) di questa pagina.
     *
     * @return string una stringa XHTML rappresentante il titolo della pagina
     * @see Compilable
     */
    function getTitle()
    {
        $authorID = $this->author->getID();
        $siteID = $this->site->getID();
        $title = a("do.php?goTo=AdminMain&amp;authorID=$authorID",
            "Il Progettista")." > ".
            a("do.php?goTo=AdminManageSite&amp;authorID=$authorID&amp;".
            "siteID=$siteID", $this->site->getShortURL())." > ".
            a("do.php?goTo=AdminListArticles&amp;authorID=$authorID&amp;".
            "siteID=$siteID","Articoli")." > ".$this->defaultTitle;
        return $title;
    }
    
    /**
     * Ritorna un array di stringhe XHTML relative al menu (barra di navigazione)
     * di questa pagina.
     *
     * @return array vettore di stringhe XHTML rappresentante il menu della pagina
     * @see Compilable
     */
    function getMenuEntries()
    {
        $authorID = $this->author->getID();
        $siteID = $this->site->getID();
        $menuEntries = array(p(a("do.php?goTo=AdminManageSite&amp;".
            "siteID=$siteID&amp;authorID=$authorID",
            "Annulla e torna alla gestione del sito").br().
            a("do.php?goTo=AdminListArticles&amp;siteID=$siteID&amp;".
            "authorID=$authorID","Annulla e torna alla gestione degli articoli")));
        return $menuEntries;
    }
    
    /**
     * Ritorna il contenuto (XHTML) del corpo di questa pagina.
     *
     * @return string la stringa XHTML rappresentante il corpo della pagina
     * @see Compilable
     */
    function getContents()
    {
        $authorID = $this->author->getID();
        $siteID = $this->site->getID();
        
        $action = "";
        $articleID = 0;
        $articleCategory = null;
        if ($this->mode == "new") {
            $action = "addArticle";
        }
        elseif ($this->mode == "edit") {
            $action = "editArticle";
            $articleID = $this->article->getID();
        }
        
        $contents = h1("Contenuti dell&#039;articolo").
            p("Da questa pagina puoi gestire i contenuti effettivi dell&#039;
            articolo.").
            form("do.php?action=$action&amp;authorID=$authorID&amp;siteID=$siteID".
            "&amp;articleID=$articleID&amp;goTo=AdminListArticles&amp;mode=$this->mode",
            "POST",
            
            p("Titolo dell&#039;articolo: ".input("text","title",$this->defaultTitle).
            br().
            
            "Parole-chiave dell&#039;articolo: ".
            input("text","keywords",$this->defaultKeywords).br().
            
            "Breve descrizione dell&#039;articolo: ".
            input("text", "description",$this->defaultDescription).br().
            
            "Contenuti dell&#039;articolo:".br().
            HTMLEditor($this->defaultContents, $this->javascript).br().
            
            "Articoli correlati a questo articolo:".br().
            $this->checkboxes().br().
            
            "Sezione a cui questo articolo appartiene: ".br().
            $this->combobox($this->defaultCategory).br().
            
            "Quando hai finito, clicca sul bottone qui sotto:".br().
            submit()
            ));
        return $contents;
    }
  
    /**
     * Ritorna il codice XHTML delle checkbox per la correlazione degli articoli
     *
     * @access private
     * @return string la stringa XHTML rappresentante le checkbox
     */
    function checkboxes()
    {
        $allArticles = $this->site->getArticles();
        $listElements = array();
        $count = 0;
        $correlatedArticleIDs = array();            
        foreach ($this->defaultCorrelatedArticles as $i) {
            $correlatedArticleIDs[] = $i->getID();
        }
        foreach ($allArticles as $i) {
            if ($this->mode=="new" || $i->getID() != $this->article->getID()) {
                $articleID = $i->getID();
                $listElements []= checkbox("article$count", in_array($articleID, $correlatedArticleIDs)).
                $i->getTitle().input("hidden", "article$count"."ID",$articleID);               
                $count++;
            }
        }
        return unorderedList($listElements);
    }
    
    /**
     * Ritorna il codice XHTML della select per la scelta della sezione
     * a cui l'articolo appartiene
     *
     * @access private
     * @param Category $category la sezione di default dell'articolo
     * @return string la stringa XHTML rappresentante la select
     */
    function combobox($category)
    {
        $selectContents = "";
        foreach ($this->site->getCategories() as $i) {
            $selectContents .= option($i->getID(), $i->getID() == $category->getID(),
                $i->getName());
        }
        
        return select("categoryID", $selectContents);
    }
}
?>
