<?php
/* vim: set expandtab tabstop=4 shiftwidth=4: */
// +----------------------------------------------------------------------+
// | MCMS: a PHP Content Management System for creating accessible sites. |
// | Copyright (C) 2006  Silvio Moioli                                    |
// |                                                                      |
// | This program is free software; you can redistribute it and/or modify |
// | it under the terms of the GNU General Public License as published by |
// | the Free Software Foundation; either version 2 of the License, or    |
// | (at your option) any later version.                                  |
// |                                                                      |
// | This program is distributed in the hope that it will be useful,      |
// | but WITHOUT ANY WARRANTY; without even the implied warranty of       |
// | MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the        |
// | GNU General Public License for more details.                         |
// |                                                                      |
// | You should have received a copy of the GNU General Public License    |
// | along with this program; if not, write to the Free Software          |
// | Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307 |
// +----------------------------------------------------------------------+
// | Authors: Silvio Moioli <silvio at moioli dot net> www.moioli.net     |
// +----------------------------------------------------------------------+
//
//$Id:

/** Importa la classe di base per l"interfaccia utente (autore) */
require_once $_SERVER["DOCUMENT_ROOT"]."/admin/lib/view/AdminPage.php";
/** Importa la libreria per semplificare l"aggiunta di tag XML */
require_once $_SERVER["DOCUMENT_ROOT"]."/admin/lib/view/Tagger.php";

/**
 * Rappresenta la pagina di modifica dei dati personali di un autore.
 * 
 * @package  MCMS
 * @version  2
 * @author   Silvio Moioli <silvio at moioli dot net>
 */
class AdminEditAuthor extends AdminPage
{
    /** @var Author l'autore da modificare */
    var $author = null;
    
    /** @var string nome proposto all'utente per questa sezione */
    var $defaultName = "Mario";
    /** @var string cognome proposto all'utente per questa sezione */
    var $defaultSurname = "Mario";
    /** @var string nickname proposto all'utente per questa sezione */
    var $defaultNick = "Supermario";
    /** @var string indirizzo email proposto all'utente per questa sezione */
    var $defaultEmail = "mario@miosito.it";
    
    /**
     * Costruttore standard.
     *
     * @see AdminPage
     * @param Author l'autore da modificare
     */
    function AdminEditAuthor($author)
    {
        parent::AdminPage();
        $this->author=$author;
        
        $this->defaultName = $this->author->getName();
        $this->defaultSurname = $this->author->getSurname();
        $this->defaultNick = $this->author->getNick();
        $this->defaultEmail = $this->author->getEmail();
    }
    
    /**
     * Cambia il nome proposto all'utente per questa sezione
     *
     * @param string $defaultName il nuovo titolo
     */
    function setDefaultName($defaultName){
        $this->defaultName = $defaultName;
    }
    
    /**
     * Cambia il cognome proposto all'utente per questa sezione
     *
     * @param string $defaultSurname il nuovo titolo
     */
    function setDefaultSurname($defaultSurname){
        $this->defaultSurname = $defaultSurname;
    }
    
    /**
     * Cambia il nickname proposto all'utente per questa sezione
     *
     * @param string $defaultNick il nuovo titolo
     */
    function setDefaultNick($defaultNick){
        $this->defaultNick = $defaultNick;
    }
   
    /**
     * Cambia l'indirizzo email proposto all'utente per questa sezione
     *
     * @param string $defaultEmail il nuovo titolo
     */
    function setDefaultEmail($defaultEmail){
        $this->defaultEmail = $defaultEmail;
    }
    
    /**
     * Ritorna il titolo (in XHTML) di questa pagina.
     *
     * @return string una stringa XHTML rappresentante il titolo della pagina
     * @see Compilable
     */
    function getTitle()
    {
        $title = a("do.php?goTo=AdminIndex", "Login al Progettista").
            " > Cambia dati di ".$this->defaultName;

        return $title;
    }
    
    /**
     * Ritorna un array di stringhe XHTML relative al menu (barra di navigazione)
     * di questa pagina.
     *
     * @return array vettore di stringhe XHTML rappresentante il menu della pagina
     * @see Compilable
     */
    function getMenuEntries()
    {
        $menuEntries = array(p(a("do.php?goTo=AdminIndex",
            "Annulla e torna alla pagina principale del Progettista")));
            
        return $menuEntries;
    }
    
    /**
     * Ritorna il contenuto (XHTML) del corpo di questa pagina.
     *
     * @return string la stringa XHTML rappresentante il corpo della pagina
     * @see Compilable
     */
    function getContents()
    {
        $authorID = $this->author->getID();
        
        $contents = h1("Ci sono anch&#039;io!").
        p("Il Progettista &egrave; sempre lieto di ricevere nuove persone
        che lavorino ai suoi siti. Ti chiede solo qualche dettaglio personale,
        per identificarti poi sulle pagine che scriverai.".br().
        "Per favore, immetti il tuo: ".br().
        form("do.php?goTo=AdminMain&amp;action=editAuthor&amp;".
            "authorID=$authorID", "POST",
            "Nome: ".input("text","name",$this->defaultName).br().
            "Cognome: ".input("text","surname",$this->defaultSurname).br().
            "Nickname Internet o soprannome: ".input("text","nick",
                $this->defaultNick).br().
            "Indirizzo email: ".input("text","email",$this->defaultEmail).br().
            "Quando hai finito, clicca sul bottone qui sotto: ".br().
            submit()
        ));
        
        return $contents;
    }
}
?>
