<?php
/* vim: set expandtab tabstop=4 shiftwidth=4: */
// +----------------------------------------------------------------------+
// | MCMS: a PHP Content Management System for creating accessible sites. |
// | Copyright (C) 2006  Silvio Moioli                                    |
// |                                                                      |
// | This program is free software; you can redistribute it and/or modify |
// | it under the terms of the GNU General Public License as published by |
// | the Free Software Foundation; either version 2 of the License, or    |
// | (at your option) any later version.                                  |
// |                                                                      |
// | This program is distributed in the hope that it will be useful,      |
// | but WITHOUT ANY WARRANTY; without even the implied warranty of       |
// | MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the        |
// | GNU General Public License for more details.                         |
// |                                                                      |
// | You should have received a copy of the GNU General Public License    |
// | along with this program; if not, write to the Free Software          |
// | Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307 |
// +----------------------------------------------------------------------+
// | Authors: Silvio Moioli <silvio at moioli dot net> www.moioli.net     |
// +----------------------------------------------------------------------+
//
//$Id:

/** Importa la classe di base per l"interfaccia utente (autore) */
require_once $_SERVER["DOCUMENT_ROOT"]."/admin/lib/view/AdminPage.php";
/** Importa la libreria per semplificare l"aggiunta di tag XML */
require_once $_SERVER["DOCUMENT_ROOT"]."/admin/lib/view/Tagger.php";

/**
 * Rappresenta la pagina di aggiunta/modifica di una sezione. E' possibile cambiare
 * il nome o la descrizione della sezione.
 * 
 * @package  MCMS
 * @version  2
 * @author   Silvio Moioli <silvio at moioli dot net>
 */
class AdminEditCategory extends AdminPage
{
    /** @var Author l'autore che accede a questa pagina */
    var $author = null;
    /** @var Site il sito a cui appartiene la sezione da modificare o aggiungere */
    var $site = null;
    /** @var Category la sezione da modificare, null se  un nuovo articolo */
    var $category = null;
    /** @var string "new" se si aggiunge una nuova sezione "edit" altrimenti */
    var $mode = "new";
    
    /** @var string nome proposto all'utente per questa sezione */
    var $defaultName = "Varie";
    /** @var string descrizione proposta all'utente per questa sezione */
    var $defaultDescription = "Tutto qui";
    
    /**
     * Costruttore standard.
     *
     * @see AdminPage
     * @param Author l'autore che accede a questa pagina
     * @param Site il sito a cui appartiene l'articolo da modificare o aggiungere
     * @param bool true se Javascript  in uso per la modifica dell'XHTML
     */
    function AdminEditCategory($author, $site, $category, $mode)
    {
        parent::AdminPage();
        $this->author=$author;    
        $this->site=$site;
        $this->category=$category;
        $this->mode=$mode;
        
        if ($mode == "edit") {
	        $this->defaultName = $this->category->getName();
   	     $this->defaultDescription = $this->category->getDescription();
   	  }
    }
    
    /**
     * Cambia il nome proposto all'utente per questa sezione
     *
     * @param string $defaultName il nuovo titolo
     */
    function setDefaultName($defaultName){
        $this->defaultName = $defaultName;
    }
    
    /**
     * Cambia la descrizione proposta all'utente per questa sezione
     *
     * @param string $defaultDescription la nuova descrizione
     */
    function setDefaultDescription($defaultDescription){
        $this->defaultDescription = $defaultDescription;
    }
   
    /**
     * Ritorna il titolo (in XHTML) di questa pagina.
     *
     * @return string una stringa XHTML rappresentante il titolo della pagina
     * @see Compilable
     */
    function getTitle()
    {
        $authorID = $this->author->getID();
        $siteID = $this->site->getID();
        
        $title = a("do.php?goTo=AdminMain&amp;authorID=$authorID",
            "Il Progettista")." > ".
            a("do.php?goTo=AdminManageSite&amp;authorID=$authorID&amp;".
            "siteID=$siteID",$this->site->getShortURL())." > ".
            a("do.php?goTo=AdminListCategories&amp;authorID=$authorID&amp;".
            "siteID=$siteID","Sezioni")." > $this->defaultName";

        return $title;
    }
    
    /**
     * Ritorna un array di stringhe XHTML relative al menu (barra di navigazione)
     * di questa pagina.
     *
     * @return array vettore di stringhe XHTML rappresentante il menu della pagina
     * @see Compilable
     */
    function getMenuEntries()
    {
        $authorID = $this->author->getID();
        $siteID = $this->site->getID();
        
        $menuEntries = array(p(a("do.php?goTo=AdminManageSite&amp;".
            "siteID=$siteID&amp;authorID=$authorID",
            "Annulla e torna alla gestione del sito").br().
            a("do.php?goTo=AdminListCategories&amp;siteID=$siteID&amp;".
            "authorID=$authorID","Annulla e torna alla gestione delle sezioni")));
            
        return $menuEntries;
    }
    
    /**
     * Ritorna il contenuto (XHTML) del corpo di questa pagina.
     *
     * @return string la stringa XHTML rappresentante il corpo della pagina
     * @see Compilable
     */
    function getContents()
    {
        $authorID = $this->author->getID();
        $siteID = $this->site->getID();
        $categoryID = 0;
        $action = "addCategory";
        if ($this->mode ==  "edit") {
            $categoryID = $this->category->getID();
            $action = "editCategory";
        }

        $contents = h1("Dettagli della sezione").
            p("Da questa pagina puoi modificare i dettagli relativi alla sezione.".
            br().
            form("do.php?goTo=AdminListCategories&amp;action=$action&amp;".
            "authorID=$authorID&amp;siteID=$siteID&amp;categoryID=$categoryID&amp;".
            "mode=$this->mode",
            "POST",
            
            "Nome della sezione: ".input("text","name",$this->defaultName).br().
            "Descrizione della sezione: ".input("text","description",
            $this->defaultDescription).br().
            "Quando hai finito, clicca sul bottone qui sotto:".br().
            submit()
            ));
        
        return $contents;
    }
}
?>
