<?php
/* vim: set expandtab tabstop=4 shiftwidth=4: */
// +----------------------------------------------------------------------+
// | MCMS: a PHP Content Management System for creating accessible sites. |
// | Copyright (C) 2006  Silvio Moioli                                    |
// |                                                                      |
// | This program is free software; you can redistribute it and/or modify |
// | it under the terms of the GNU General Public License as published by |
// | the Free Software Foundation; either version 2 of the License, or    |
// | (at your option) any later version.                                  |
// |                                                                      |
// | This program is distributed in the hope that it will be useful,      |
// | but WITHOUT ANY WARRANTY; without even the implied warranty of       |
// | MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the        |
// | GNU General Public License for more details.                         |
// |                                                                      |
// | You should have received a copy of the GNU General Public License    |
// | along with this program; if not, write to the Free Software          |
// | Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307 |
// +----------------------------------------------------------------------+
// | Authors: Silvio Moioli <silvio at moioli dot net> www.moioli.net     |
// +----------------------------------------------------------------------+
//
//$Id:

/** Importa la classe di base per l'interfaccia utente (autore) */
require_once $_SERVER["DOCUMENT_ROOT"]."/admin/lib/view/AdminPage.php";
/** Importa la libreria per semplificare l'aggiunta di tag XML */
require_once $_SERVER["DOCUMENT_ROOT"]."/admin/lib/view/Tagger.php";

/**
 * Rappresenta la pagina di modifica della homepage del sito.
 * Presenta una finestra per l'input dell'XHTML.
 * 
 * @package  MCMS
 * @version  2
 * @author   Silvio Moioli <silvio at moioli dot net>
 */
class AdminEditHomepage extends AdminPage
{
    /** @var Author l'autore che accede a questa pagina */
    var $author = null;
    /** @var Site il sito a cui appartiene l'articolo da modificare o aggiungere */
    var $site = null;
    /** @var bool true se Javascript  in uso per la modifica dell'XHTML */
    var $javascript = true;
        
    /** @var string motto proposto all'utente per questo sito */
    var $defaultSlogan = "Questo  il mio nuovo sito!";
    /** @var string parole chiave proposte all'utente per questo sito */
    var $defaultKeywords = "parole chiave";
    /** @var string contenuti (XHTML) proposti all'utente per 
        l'homepage di questo sito */
    var $defaultContents = "Inserisci i tuoi contenuti <b>qui</b>.";
    
    /**
     * Costruttore standard.
     *
     * @see AdminPage
     * @param Author l'autore che accede a questa pagina
     * @param Site il sito a cui appartiene l'articolo da modificare o aggiungere
     * @param bool true se Javascript  in uso per la modifica dell'XHTML
     */
    function AdminEditHomepage($author, $site, $javascript)
    {
        parent::AdminPage();
        $this->author=$author;    
        $this->site=$site;
        $this->javascript=$javascript;
        
        $homepage = $this->site->getHomepage();
        $this->defaultSlogan = $homepage->getSlogan();
        $this->defaultKeywords = $homepage->getKeywords();
        $this->defaultContents = $homepage->getContents();
    }
    
    /**
     * Cambia il motto proposto all'utente per questa notizia
     *
     * @param string $defaultSlogan il nuovo motto
     */
    function setDefaultSlogan($defaultSlogan)
    {
        $this->defaultSlogan = $defaultSlogan;
    }
    
    /**
     * Cambia le parole chiave proposte all'utente per questa notizia
     *
     * @param string $defaultKeywords le nuove parole chiave
     */
    function setDefaultKeywords($defaultKeywords)
    {
        $this->defaultKeywords = $defaultKeywords;
    }
    
    /**
     * Cambia i contenuti (XHTML) proposti all'utente per questa notizia
     *
     * @param string $defaultContents i nuovi contenuti
     */
    function setDefaultContents($defaultContents)
    {
        $this->defaultContents = $defaultContents;
    }
   
    /**
     * Ritorna il titolo (in XHTML) di questa pagina.
     *
     * @return string una stringa XHTML rappresentante il titolo della pagina
     * @see Compilable
     */
    function getTitle()
    {
        $authorID = $this->author->getID();
        $siteID = $this->site->getID();
        
        $title = a("do.php?goTo=AdminMain&amp;authorID=$authorID",
            "Il Progettista")." > ".
            a("do.php?goTo=AdminManageSite&amp;authorID=$authorID&amp;".
            "siteID=$siteID",$this->site->getShortURL())." > Homepage";

        return $title;
    }
    
    /**
     * Ritorna un array di stringhe XHTML relative al menu (barra di navigazione)
     * di questa pagina.
     *
     * @return array vettore di stringhe XHTML rappresentante il menu della pagina
     * @see Compilable
     */
    function getMenuEntries()
    {
        $authorID = $this->author->getID();
        $siteID = $this->site->getID();
        
        $menuEntries = array(p(a("do.php?goTo=AdminManageSite&amp;".
            "siteID=$siteID&amp;authorID=$authorID",
            "Annulla e torna alla gestione del sito")));
            
        return $menuEntries;
    }
    
    /**
     * Ritorna il contenuto (XHTML) del corpo di questa pagina.
     *
     * @return string la stringa XHTML rappresentante il corpo della pagina
     * @see Compilable
     */
    function getContents()
    {
        $authorID = $this->author->getID();
        $siteID = $this->site->getID();

        $contents = h1("Dettagli della homepage").
        p("Da questa pagina puoi modificare i dettagli relativi alla pagina 
        iniziale del sito. Puoi modificare l&#039;homepage solo se sei il ".
        b("fondatore")." del sito.".br().
        form("do.php?goTo=AdminManageSite&amp;action=editHomepage&amp;".
            "authorID=$authorID&amp;siteID=$siteID", "POST",
        
            p("Motto dell&#039;homepage (e del sito): ".
            input("text","slogan",$this->defaultSlogan).br().
            "Parole-chiave dell&#039;homepage (e del sito): ".
            input("text","keywords",$this->defaultKeywords).br().
            HTMLEditor($this->defaultContents, $this->javascript).br().
            
            "Quando hai finito, clicca sul bottone qui sotto:".br().
            submit()
        )));
        
        return $contents;
    }
}
?>
