<?php
/* vim: set expandtab tabstop=4 shiftwidth=4: */
// +----------------------------------------------------------------------+
// | MCMS: a PHP Content Management System for creating accessible sites. |
// | Copyright (C) 2006  Silvio Moioli                                    |
// |                                                                      |
// | This program is free software; you can redistribute it and/or modify |
// | it under the terms of the GNU General Public License as published by |
// | the Free Software Foundation; either version 2 of the License, or    |
// | (at your option) any later version.                                  |
// |                                                                      |
// | This program is distributed in the hope that it will be useful,      |
// | but WITHOUT ANY WARRANTY; without even the implied warranty of       |
// | MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the        |
// | GNU General Public License for more details.                         |
// |                                                                      |
// | You should have received a copy of the GNU General Public License    |
// | along with this program; if not, write to the Free Software          |
// | Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307 |
// +----------------------------------------------------------------------+
// | Authors: Silvio Moioli <silvio at moioli dot net> www.moioli.net     |
// +----------------------------------------------------------------------+
//
//$Id:

/** Importa la classe di base per l"interfaccia utente (autore) */
require_once $_SERVER["DOCUMENT_ROOT"]."/admin/lib/view/AdminPage.php";
/** Importa la libreria per semplificare l"aggiunta di tag XML */
require_once $_SERVER["DOCUMENT_ROOT"]."/admin/lib/view/Tagger.php";

/**
 * Rappresenta la pagina di modifica di una notizia. Presenta una finestra
 * per l'input dell'XHTML.
 * 
 * @package  MCMS
 * @version  2
 * @author   Silvio Moioli <silvio at moioli dot net>
 */
class AdminEditNews extends AdminPage {

    /** @var Author l'autore che accede a questa pagina */
    var $author = null;
    /** @var Site il sito a cui appartiene la notizia da modificare o aggiungere */
    var $site = null;
    /** @var News la notizia da modificare, null se  una nuova notizia */
    var $news = null;
    /** @var string "new" se si aggiunge una nuova notizia o "edit" altrimenti */
    var $mode = "new";
    /** @var bool true se Javascript  in uso per la modifica dell'XHTML */
    var $javascript = true;
    
    /** @var string titolo proposto all'utente per questa notizia */
    var $defaultTitle = "Nuova notizia";
    /** @var string parole chiave proposte all'utente per questa notizia */
    var $defaultKeywords = "parole chiave";
    /** @var string fonte proposta all'utente per questa notizia */
    var $defaultSource = "";
    /** @var string contenuti (XHTML) proposti all'utente per questa notizia */
    var $defaultContents = "Inserisci i tuoi contenuti <b>qui</b>.";
    /** @var array articoli correlati proposti all'utente per questo notizia */
    var $defaultCorrelatedArticles = array();
    
    /**
     * Costruttore standard.
     *
     * @see AdminPage
     * @param Author $author l'autore della nuova notizia o della notizia
     * da modificare
     * @param Site $site il sito a cui la nuova notizia o la notizia da
     * modificare appartiene
     * @param News $news la notizia da modificare o null 
     * @param string $mode "new" o "modify" a seconda che si voglia creare
     * una nuova notizia o modificarne una esistente 
     * @param bool $javascript indica la possibilit di usare il JavaScript
     * per l'editor XHTML
     */
    function AdminEditNews($author, $site, $news, $mode, $javascript)
    {
        parent::AdminPage();
        $this->author=$author;    
        $this->site=$site;
        $this->news=$news;
        $this->mode=$mode;
        $this->javascript=$javascript;
        if ($mode == "edit"){
            $this->defaultTitle = $news->getTitle();
            $this->defaultKeywords = $news->getKeywords();
            $this->defaultSource = $news->getSource();
            $this->defaultContents = $news->getContents();
            $this->defaultCorrelatedArticles = $news->getCorrelatedArticles();
        }
    }
    
    /**
     * Cambia il titolo proposto all'utente per questa notizia
     *
     * @param string $defaultTitle il nuovo titolo
     */
    function setDefaultTitle($defaultTitle)
    {
        $this->defaultTitle = $defaultTitle;
    }
    
    /**
     * Cambia le parole chiave proposte all'utente per questa notizia
     *
     * @param string $defaultKeywords le nuove parole chiave
     */
    function setDefaultKeywords($defaultKeywords)
    {
        $this->defaultKeywords = $defaultKeywords;
    }
    
    /**
     * Cambia la fonte proposta all'utente per questa notizia
     *
     * @param string $defaultSource la nuova fonte
     */
    function setDefaultSource($defaultSource)
    {
        $this->defaultSource = $defaultSource;
    }
    
    /**
     * Cambia i contenuti (XHTML) proposti all'utente per questa notizia
     *
     * @param string $defaultContents i nuovi contenuti
     */
    function setDefaultContents($defaultContents)
    {
        $this->defaultContents = $defaultContents;
    }
    
    /**
     * Cambia gli articoli correlati proposti all'utente per questa notizia
     *
     * @param array $defaultCorrelatedArticles i nuovi articoli correlati
     */
    function setDefaultCorrelatedArticles($defaultCorrelatedArticles)
    {
        $this->defaultCorrelatedArticles = $defaultCorrelatedArticles;
    }
   
    /**
     * Ritorna il titolo (in XHTML) di questa pagina.
     *
     * @return string una stringa XHTML rappresentante il titolo della pagina
     * @see Compilable
     */
    function getTitle()
    {
        $authorID = $this->author->getID();
        $siteID = $this->site->getID();
        $title = a("do.php?goTo=AdminMain&amp;authorID=$authorID",
            "Il Progettista")." > ".
            a("do.php?goTo=AdminManageSite&amp;authorID=$authorID&amp;".
            "siteID=$siteID", $this->site->getShortURL())." > ".
            a("do.php?goTo=AdminListNews&amp;authorID=$authorID&amp;".
            "siteID=$siteID","Notizie")." > ".$this->defaultTitle;
        return $title;
    }
    
    /**
     * Ritorna un array di stringhe XHTML relative al menu (barra di navigazione)
     * di questa pagina.
     *
     * @return array vettore di stringhe XHTML rappresentante il menu della pagina
     * @see Compilable
     */
    function getMenuEntries()
    {
        $authorID = $this->author->getID();
        $siteID = $this->site->getID();
        $menuEntries = array(p(a("do.php?goTo=AdminManageSite&amp;".
            "siteID=$siteID&amp;authorID=$authorID",
            "Annulla e torna alla gestione del sito").br().
            a("do.php?goTo=AdminListNews&amp;siteID=$siteID&amp;authorID=$authorID",
            "Annulla e torna alla gestione delle notizie")));
        return $menuEntries;
    }
    
    /**
     * Ritorna il contenuto (XHTML) del corpo di questa pagina.
     *
     * @return string la stringa XHTML rappresentante il corpo della pagina
     * @see Compilable
     */
    function getContents()
    {
        $authorID = $this->author->getID();
        $siteID = $this->site->getID();
        $newsID = 0;
        $action = "addNews";
        if ($this->news != null){
            $newsID = $this->news->getID();
            $action = "editNews";
        }
        
        $contents = h1("Contenuti della notizia").
            p("Da questa pagina puoi gestire i contenuti della notizia.").
            form("do.php?action=$action&amp;authorID=$authorID&amp;".
            "siteID=$siteID&amp;newsID=$newsID&amp;goTo=AdminListNews&amp;mode=$this->mode", "POST",
            
            p("Titolo della notizia: ".
            input("text","title","$this->defaultTitle").br().
            "Parole-chiave della notizia: ".
            input("text","keywords","$this->defaultKeywords").br().
            "URL della fonte da cui la notizia &egrave; tratta: ".
            input("text","source","$this->defaultSource").br().
            "Il progettista consiglia: puoi lasciare questo campo vuoto se la 
            notizia &egrave; tua!".br().
            "Contenuti della notizia:".br().
            HTMLEditor($this->defaultContents, $this->javascript).br().
            "Articoli correlati a questa notizia:".br().
            $this->checkboxes().br().
            "Quando hai finito, clicca sul bottone qui sotto:".br().
            submit()
        ));
        
        return $contents;
    }
    
    /**
     * Ritorna il codice XHTML delle checkbox per la correlazione degli articoli
     *
     * @access private
     * @return string la stringa XHTML rappresentante le checkbox
     */
    function checkboxes()
    {
        $allArticles = $this->site->getArticles();
        $listElements = array();
        $count = 0;
        $correlatedArticleIDs = array();            
        foreach ($this->defaultCorrelatedArticles as $i) {
            $correlatedArticleIDs[] = $i->getID();
        }
        foreach ($allArticles as $i) {
            $articleID = $i->getID();
            $listElements []= checkbox("article$count", in_array($articleID, $correlatedArticleIDs)).
            $i->getTitle().input("hidden", "article$count"."ID",$articleID);               
            $count++;
        }
        return unorderedList($listElements);
    }
}
?>
