<?php
/* vim: set expandtab tabstop=4 shiftwidth=4: */
// +----------------------------------------------------------------------+
// | MCMS: a PHP Content Management System for creating accessible sites. |
// | Copyright (C) 2006  Silvio Moioli                                    |
// |                                                                      |
// | This program is free software; you can redistribute it and/or modify |
// | it under the terms of the GNU General Public License as published by |
// | the Free Software Foundation; either version 2 of the License, or    |
// | (at your option) any later version.                                  |
// |                                                                      |
// | This program is distributed in the hope that it will be useful,      |
// | but WITHOUT ANY WARRANTY; without even the implied warranty of       |
// | MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the        |
// | GNU General Public License for more details.                         |
// |                                                                      |
// | You should have received a copy of the GNU General Public License    |
// | along with this program; if not, write to the Free Software          |
// | Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307 |
// +----------------------------------------------------------------------+
// | Authors: Silvio Moioli <silvio at moioli dot net> www.moioli.net     |
// +----------------------------------------------------------------------+
//
//$Id:

/** Importa la classe di base per l'interfaccia utente (autore) */
require_once $_SERVER["DOCUMENT_ROOT"]."/admin/lib/view/AdminPage.php";
/** Importa la libreria per semplificare l'aggiunta di tag XML */
require_once $_SERVER["DOCUMENT_ROOT"]."/admin/lib/view/Tagger.php";

/**
 * Pagina utilizzata per avvertire l'utente dell'immissione di dati non
 * validi.
 * 
 * @package  MCMS
 * @version  2
 * @author   Silvio Moioli <silvio at moioli dot net>
 */
class AdminError extends AdminPage
{
    /** @var string Il messaggio di errore da mostrare all'utente */
    var $errorMessage = "Errore";
    /** @var array Eventuali parametri GET della pagina $returnTo */
    var $params = array();

    /**
     * Costruttore standard.
     *
     * @param string $errorMessage Il messaggio di errore da mostrare all'utente
     * @param string $returnTo La pagina a cui andare dopo la segnalazione d'errore
     * @param string $params Eventuali parametri GET della pagina $returnTo
     * @see AdminPage
     */
    function AdminError($errorMessage, $returnTo, $params)
    {
        parent::AdminPage();
        $this->errorMessage=$errorMessage;    
        $this->params=$params;
        //Disabilitiamo l'azione in corso (che ha generato l'errore)
        unset($this->params["action"]);
        //Rimpiazziamo la pagina di ritorno
        $this->params["goTo"]=$returnTo;
    }
    
    /**
     * Ritorna il titolo (in XHTML) di questa pagina.
     *
     * @return string una stringa XHTML rappresentante il titolo della pagina
     * @see Compilable
     */
    function getTitle()
    {
        return "Errore di immissione dei dati";
    }
    
    /**
     * Ritorna un array di stringhe XHTML relative al menu (barra di navigazione)
     * di questa pagina.
     *
     * @return array vettore di stringhe XHTML rappresentante il menu della pagina
     * @see Compilable
     */
    function getMenuEntries()
    {
        return "Torna alla ".a("do.php?goTo=AdminIndex",
            "Torna alla selezione degli autori");
    }
    
    /**
     * Ritorna il contenuto (XHTML) del corpo di questa pagina.
     *
     * @return string la stringa XHTML rappresentante il corpo della pagina
     * @see Compilable
     */
    function getContents()
    {
        $url = "do.php?";
        foreach ($this->params as $key => $value) {
            $url .= "$key=$value&amp;";
        }
        $contents = p("Si &egrave; verificato un errore: ".b($this->errorMessage).br().
            a($url,"Torna alla pagina precedente"));
        
        return $contents;
    }
}

?>
