<?php
/* vim: set expandtab tabstop=4 shiftwidth=4: */
// +----------------------------------------------------------------------+
// | MCMS: a PHP Content Management System for creating accessible sites. |
// | Copyright (C) 2006  Silvio Moioli                                    |
// |                                                                      |
// | This program is free software; you can redistribute it and/or modify |
// | it under the terms of the GNU General Public License as published by |
// | the Free Software Foundation; either version 2 of the License, or    |
// | (at your option) any later version.                                  |
// |                                                                      |
// | This program is distributed in the hope that it will be useful,      |
// | but WITHOUT ANY WARRANTY; without even the implied warranty of       |
// | MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the        |
// | GNU General Public License for more details.                         |
// |                                                                      |
// | You should have received a copy of the GNU General Public License    |
// | along with this program; if not, write to the Free Software          |
// | Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307 |
// +----------------------------------------------------------------------+
// | Authors: Silvio Moioli <silvio at moioli dot net> www.moioli.net     |
// +----------------------------------------------------------------------+
//
//$Id:

/** Importa la classe di base per l"interfaccia utente (autore) */
require_once $_SERVER["DOCUMENT_ROOT"]."/admin/lib/view/AdminPage.php";
/** Importa la libreria per semplificare l"aggiunta di tag XML */
require_once $_SERVER["DOCUMENT_ROOT"]."/admin/lib/view/Tagger.php";

/**
 * Rappresenta la pagina di gestione degli articoli. Viene mostrato un elenco da
 * cui  possibile scegliere di modificare, cancellare o aggiungere articoli al
 * sito.
 * 
 * @package  MCMS
 * @version  2
 * @author   Silvio Moioli <silvio at moioli dot net>
 */
class AdminListArticles extends AdminPage
{
    /** @var Author l'autore che accede a questa pagina */
    var $author = null;
    /** @var Site il sito di cui mostrare gli articolo */
    var $site = null;
    
    /**
     * Costruttore di default
     *
     * @see AdminPage
     */
    function AdminListArticles($author, $site)
    {
        parent::AdminPage();
        $this->author=$author;
        $this->site=$site;
    }
    
    /**
     * Ritorna il titolo (in XHTML) di questa pagina.
     *
     * @return string una stringa XHTML rappresentante il titolo della pagina
     * @see Compilable
     */
    function getTitle()
    {
        $authorID = $this->author->getID();
        $siteID = $this->site->getID();
        
        $title = a("do.php?goTo=AdminMain&amp;authorID=$authorID",
            "Il Progettista")." > ".a("do.php?goTo=AdminManageSite&amp;".
            "authorID=$authorID&amp;siteID=$siteID",$this->site->getShortURL()).
            " > Articoli";
        return $title;
    }
    
    /**
     * Ritorna un array di stringhe XHTML relative al menu (barra di navigazione)
     * di questa pagina.
     *
     * @return array vettore di stringhe XHTML rappresentante il menu della pagina
     * @see Compilable
     */
    function getMenuEntries()
    {
        $authorID = $this->author->getID();
        $siteID = $this->site->getID();
    
        $menuEntries = array(p(a("do.php?goTo=AdminManageSite&amp;".
            "siteID=$siteID&amp;authorID=$authorID","Torna alla gestione del sito").
            br().a("../index$siteID.html", "Vedi il tuo sito!")));
        
        return $menuEntries;
    }
    
    /**
     * Ritorna il contenuto (XHTML) del corpo di questa pagina.
     *
     * @return string la stringa XHTML rappresentante il corpo della pagina
     * @see Compilable
     */
    function getContents()
    {
        $authorID = $this->author->getID();
        $siteID = $this->site->getID();
        
        $contents = h1("Gli articoli del sito ".a("../index$siteID.html",
            $this->site->getShortURL())).
            p("Da questa pagina puoi gestire gli articoli del tuo sito, rimuovendoli, 
            modificandoli o cambiandoli di sezione a tuo piacere.".br().
            "Il Progettista consiglia: articoli ricchi, leggibili e ben organizzati 
            sono alla base di qualsiasi buon sito!").
            h2(a("do.php?goTo=AdminEditArticle&amp;authorID=$authorID&amp;".
            "siteID=$siteID&amp;mode=new","Aggiungi nuovo articolo..."));
        
        $articles = $this->site->getArticles();
        foreach ($articles as $i) {
            $articleID = $i->getID();
            $articleAuthor = $i->getAuthor();
            $articleAuthorID = $articleAuthor->getID();
            $category = $i->getCategory();
            $categoryName = $category->getName();
            $contents .= h2($i->getTitle()." nella categoria: 
                \"$categoryName\"");
            
            if ($authorID == $articleAuthorID) {
                $contents .= unorderedList(array(
                    a("do.php?goTo=AdminEditArticle&amp;authorID=$authorID&amp;".
                        "siteID=$siteID&amp;articleID=$articleID&amp;mode=edit",
                        "Modifica articolo"),
                    a("do.php?goTo=AdminDropArticle&amp;authorID=$authorID&amp;".
                        "siteID=$siteID&amp;".
                    "articleID=$articleID","Cancella articolo")
                ));
            }
            else{
                $contents .= p("Non puoi modificare questo articolo 
                perch&egrave; non ne sei l'autore.");
            }
        }
        return $contents;
    }   
}
?>
