<?php
/* vim: set expandtab tabstop=4 shiftwidth=4: */
// +----------------------------------------------------------------------+
// | MCMS: a PHP Content Management System for creating accessible sites. |
// | Copyright (C) 2006  Silvio Moioli                                    |
// |                                                                      |
// | This program is free software; you can redistribute it and/or modify |
// | it under the terms of the GNU General Public License as published by |
// | the Free Software Foundation; either version 2 of the License, or    |
// | (at your option) any later version.                                  |
// |                                                                      |
// | This program is distributed in the hope that it will be useful,      |
// | but WITHOUT ANY WARRANTY; without even the implied warranty of       |
// | MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the        |
// | GNU General Public License for more details.                         |
// |                                                                      |
// | You should have received a copy of the GNU General Public License    |
// | along with this program; if not, write to the Free Software          |
// | Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307 |
// +----------------------------------------------------------------------+
// | Authors: Silvio Moioli <silvio at moioli dot net> www.moioli.net     |
// +----------------------------------------------------------------------+
//
//$Id:

/** Importa la classe di base per l"interfaccia utente (autore) */
require_once $_SERVER["DOCUMENT_ROOT"]."/admin/lib/view/AdminPage.php";
/** Importa la libreria per semplificare l"aggiunta di tag XML */
require_once $_SERVER["DOCUMENT_ROOT"]."/admin/lib/view/Tagger.php";

/**
 * Rappresenta la pagina di gestione delle sezioni. Viene mostrato un elenco da
 * cui  possibile scegliere di modificare, cancellare o aggiungere sezioni al
 * sito.
 * 
 * @package  MCMS
 * @version  2
 * @author   Silvio Moioli <silvio at moioli dot net>
 */
class AdminListCategories extends AdminPage
{
    /** @var Author l'autore che accede a questa pagina */
    var $author = null;
    /** @var Site il sito di cui mostrare le sezioni */
    var $site = null;
    
    /**
     * Costruttore di default
     *
     * @param Author l'autore che accede a questa pagina
     * @param Site il sito di cui mostrare le sezioni
     * @see AdminPage
     */
    function AdminListCategories($author, $site)
    {
        parent::AdminPage();
        $this->author=$author;
        $this->site=$site;
    }
    
    /**
     * Ritorna il titolo (in XHTML) di questa pagina.
     *
     * @return string una stringa XHTML rappresentante il titolo della pagina
     * @see Compilable
     */
    function getTitle()
    {
        $authorID = $this->author->getID();
        $siteID = $this->site->getID();
        
        $title = a("do.php?goTo=AdminMain&amp;authorID=$authorID",
            "Il Progettista")." > ".
            a("do.php?goTo=AdminManageSite&amp;authorID=$authorID".
            "&amp;siteID=$siteID",$this->site->getShortURL())." > Sezioni";
        return $title;
    }
    
    /**
     * Ritorna un array di stringhe XHTML relative al menu (barra di navigazione)
     * di questa pagina.
     *
     * @return array vettore di stringhe XHTML rappresentante il menu della pagina
     * @see Compilable
     */
    function getMenuEntries()
    {
        $authorID = $this->author->getID();
        $siteID = $this->site->getID();
    
        $menuEntries = array(p(a("do.php?goTo=AdminManageSite&amp;".
            "siteID=$siteID&amp;authorID=$authorID","Torna alla gestione del sito").
            br().a("../index$siteID.html","Vedi il tuo sito!")));
        
        return $menuEntries;
    }
    
    /**
     * Ritorna il contenuto (XHTML) del corpo di questa pagina.
     *
     * @return string la stringa XHTML rappresentante il corpo della pagina
     * @see Compilable
     */
    function getContents()
    {
        $authorID = $this->author->getID();
        $siteID = $this->site->getID();
        
        $contents = h1("Le sezioni del sito ".
            a("../index$siteID.html",$this->site->getShortURL()));
        $contents .= p("Da questa pagina puoi gestire le sezioni del tuo sito,
            rimuovendole o modificandole a tuo piacere. Le sezioni sono come dei
            contenitori per i tuoi articoli, in modo da poterli organizzare.
            Puoi modificare le sezioni solo se sei il ".b("fondatore")." del sito.");
    
        $contents .= h2(a("do.php?goTo=AdminEditCategory&amp;".
            "authorID=$authorID&amp;siteID=$siteID&amp;mode=new","Aggiungi nuova sezione..."));
        
        $categories = $this->site->getCategories();
        foreach ($categories as $i) {
            $categoryID = $i->getID();
            $categoryName = $i->getName();
            $contents .= h2("Sezione \"".$i->getName()."\"").
                unorderedList(array(
                    a("do.php?goTo=AdminEditCategory&amp;authorID=$authorID&amp;".
                    "siteID=$siteID&amp;categoryID=$categoryID&amp;mode=edit","Modifica sezione"),
                    a("do.php?goTo=AdminDropCategory&amp;authorID=$authorID&amp;".
                    "siteID=$siteID&amp;categoryID=$categoryID","Cancella sezione")
                ));
        }
        
        return $contents;
    }
}
?>
