<?php
/* vim: set expandtab tabstop=4 shiftwidth=4: */
// +----------------------------------------------------------------------+
// | MCMS: a PHP Content Management System for creating accessible sites. |
// | Copyright (C) 2006  Silvio Moioli                                    |
// |                                                                      |
// | This program is free software; you can redistribute it and/or modify |
// | it under the terms of the GNU General Public License as published by |
// | the Free Software Foundation; either version 2 of the License, or    |
// | (at your option) any later version.                                  |
// |                                                                      |
// | This program is distributed in the hope that it will be useful,      |
// | but WITHOUT ANY WARRANTY; without even the implied warranty of       |
// | MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the        |
// | GNU General Public License for more details.                         |
// |                                                                      |
// | You should have received a copy of the GNU General Public License    |
// | along with this program; if not, write to the Free Software          |
// | Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307 |
// +----------------------------------------------------------------------+
// | Authors: Silvio Moioli <silvio at moioli dot net> www.moioli.net     |
// +----------------------------------------------------------------------+
//
//$Id:

/** Importa la classe di base per l"interfaccia utente (autore) */
require_once $_SERVER["DOCUMENT_ROOT"]."/admin/lib/view/AdminPage.php";
/** Importa la libreria per semplificare l"aggiunta di tag XML */
require_once $_SERVER["DOCUMENT_ROOT"]."/admin/lib/view/Tagger.php";

/**
 * Rappresenta la pagina di gestione delle notizie. Viene mostrato un elenco da
 * cui  possibile scegliere di modificare, cancellare o aggiungere notizie al
 * sito.
 * 
 * @package  MCMS
 * @version  2
 * @author   Silvio Moioli <silvio at moioli dot net>
 */
class AdminListNews extends AdminPage
{
    /** @var Author l'autore che accede a questa pagina */
    var $author = null;
    /** @var Site il sito di cui mostrare le notizie */
    var $site = null;
    
    /**
     * Costruttore di default
     *
     * @param Author $author l'autore che accede a questa pagina
     * @param Site $site il sito di cui mostrare le notizie 
     * @see AdminPage
     */
    function AdminListNews($author, $site)
    {
        parent::AdminPage();
        $this->author=$author;
        $this->site=$site;
    }
    
    /**
     * Ritorna il titolo (in XHTML) di questa pagina.
     *
     * @return string una stringa XHTML rappresentante il titolo della pagina
     * @see Compilable
     */
    function getTitle()
    {
        $authorID = $this->author->getID();
        $siteID = $this->site->getID();
        
        $title = a("do.php?goTo=AdminMain&amp;authorID=$authorID",
            "Il Progettista")." > ".
            a("do.php?goTo=AdminManageSite&amp;authorID=$authorID".
            "&amp;siteID=$siteID",$this->site->getShortURL())." > Notizie";
        
        return $title;
    }
    
    /**
     * Ritorna un array di stringhe XHTML relative al menu (barra di navigazione)
     * di questa pagina.
     *
     * @return array vettore di stringhe XHTML rappresentante il menu della pagina
     * @see Compilable
     */
    function getMenuEntries()
    {
        $authorID = $this->author->getID();
        $siteID = $this->site->getID();
    
        $menuEntries = array(p(a("do.php?goTo=AdminManageSite&amp;".
            "siteID=$siteID&amp;authorID=$authorID","Torna alla gestione del sito").
            br().a("../index$siteID.html", "Vedi il tuo sito!")));
        
        return $menuEntries;
    }
    
    /**
     * Ritorna il contenuto (XHTML) del corpo di questa pagina.
     *
     * @return string la stringa XHTML rappresentante il corpo della pagina
     * @see Compilable
     */
    function getContents()
    {
        $authorID = $this->author->getID();
        $siteID = $this->site->getID();
        
        $contents = h1("Le notizie del sito ".a("../index$siteID.html",
        $this->site->getShortURL())).
        p("Da questa pagina puoi gestire le notizie del tuo sito, rimuovendole o
        cambiandole a tuo piacere.".br().
        "Il Progettista consiglia: usare molto le notizie &egrave; 
        di moda ultimamente, specialmente nei Blog.").
        h2(a("do.php?authorID=$authorID&amp;siteID=$siteID&amp;goTo=AdminEditNews".
            "&amp;mode=new", "Aggiungi nuova notizia..."));
        
        $newslist = $this->site->getNews();
        foreach ($newslist as $i) {
            $newsID = $i->getID();
            $author = $i->getAuthor();
            $newsAuthorID = $author->getID();
            $contents .= h2($i->getTitle().", ".$i->getDate());
            if ($this->author->getID() == $newsAuthorID) {
                $contents .= unorderedList(array(
                    a("do.php?goTo=AdminEditNews&amp;authorID=$authorID&amp;".
                    "siteID=$siteID&amp;newsID=$newsID&amp;mode=edit",
                    "Modifica notizia"),
                    a("do.php?goTo=AdminDropNews&amp;authorID=$authorID&amp;".
                    "siteID=$siteID&amp;newsID=$newsID","Cancella notizia")));
            }
            else {
                $contents .= p("Non puoi modificare questa notizia perch&egrave; ".
                    " non ne sei l&quot;autore.");
            }
        }
        
        return $contents;
    }
}
?>
