<?php
/* vim: set expandtab tabstop=4 shiftwidth=4: */
// +----------------------------------------------------------------------+
// | MCMS: a PHP Content Management System for creating accessible sites. |
// | Copyright (C) 2006  Silvio Moioli                                    |
// |                                                                      |
// | This program is free software; you can redistribute it and/or modify |
// | it under the terms of the GNU General Public License as published by |
// | the Free Software Foundation; either version 2 of the License, or    |
// | (at your option) any later version.                                  |
// |                                                                      |
// | This program is distributed in the hope that it will be useful,      |
// | but WITHOUT ANY WARRANTY; without even the implied warranty of       |
// | MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the        |
// | GNU General Public License for more details.                         |
// |                                                                      |
// | You should have received a copy of the GNU General Public License    |
// | along with this program; if not, write to the Free Software          |
// | Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307 |
// +----------------------------------------------------------------------+
// | Authors: Silvio Moioli <silvio at moioli dot net> www.moioli.net     |
// +----------------------------------------------------------------------+
//
//$Id:

/** Importa la classe di base per l'interfaccia utente (autore) */
require_once $_SERVER["DOCUMENT_ROOT"]."/admin/lib/view/AdminPage.php";
/** Importa la libreria per semplificare l'aggiunta di tag XML */
require_once $_SERVER["DOCUMENT_ROOT"]."/admin/lib/view/Tagger.php";
/** Carica il gestore dei template (Smarty) */
require_once $_SERVER["DOCUMENT_ROOT"]."/admin/include/smarty/libs/Smarty.class.php";

/**
 * La pagina con il form per con la richiesta della password.
 * 
 * @package  MCMS
 * @version  2
 * @author   Silvio Moioli <silvio at moioli dot net>
 */
class AdminLogin extends AdminPage
{
    /** @var Author l'autore che deve essere autenticato */
    var $author = null;
    
    /**
     * Costruttore di default
     *
     * @param Author $author l'autore che deve essere autenticato 
     * @see AdminPage
     */
    function AdminLogin($author)
    {
        parent::AdminPage();
        $this->author=$author;
    }
    
    /**
     * Ritorna il titolo (in XHTML) di questa pagina.
     *
     * @return string una stringa XHTML rappresentante il titolo della pagina
     * @see Compilable
     */
    function getTitle()
    {        
        return "Password richiesta!";
    }
    
    /**
     * Ritorna un array di stringhe XHTML relative al menu (barra di navigazione)
     * di questa pagina.
     *
     * @return array vettore di stringhe XHTML rappresentante il menu della pagina
     * @see Compilable
     */
    function getMenuEntries()
    {
        $authorID = $this->author->getID();
    
        $menuEntries = array("Immetti la tua password oppure...");
        $menuEntries [] = p(a("do.php?goTo=AdminIndex",
            "Torna alla selezione degli autori"));
        
        return $menuEntries;
    }
    
    /**
     * Ritorna il contenuto (XHTML) del corpo di questa pagina.
     *
     * @return string la stringa XHTML rappresentante il corpo della pagina
     * @see Compilable
     */
    function getContents()
    {
        $authorID = $this->author->getID();
        
        $contents = p("Immetti la tua password nel campo qui sotto:");
    
        $action = "do.php?";
        $formContents = "";
        //Ricopia le variabili GET e POST se presenti
        if (isset($_GET)) {
            foreach ($_GET as $key => $value) {
                $action .= "$key=$value&amp;";
            }
        }
        if (isset($_POST)) {
            foreach ($_POST as $key => $value) {
                $formContents .= input("hidden", $key, $value);
            }
        }
                           
        $formContents .= "Autore: ".getAuthorSignature($this->author).br();
        $formContents .= input("hidden", "username", $this->author->getID()).br();
        $formContents .= input("password", "password", "").br();
        $formContents .= submit();
        
        $contents .= form($action, "POST", $formContents);
        
        return $contents;
    }
    
   /**
    * Questo metodo viene passato ad Auth per la visualizzazione della
    * pagina di login.
    */
    function displayLoginPage()
    {
        $compiler = new Compiler();
        $compiler->display($this);
    }
    
    /**
     * Compila la pagina e la visualizza all'utente.
     */
    function display()
    {
        $smarty = new Smarty();
        //Assegno le variabili a Smarty
        $smarty->assign('title',$this->getTitle());
        $smarty->assign('menuEntries',$this->getMenuEntries());
        $smarty->assign('contents',$this->getContents());
    
        //Elaboro la pagina vera e propria
        $smarty->display("adminTemplate.tpl");
    }
}

?>
