<?php
/* vim: set expandtab tabstop=4 shiftwidth=4: */
// +----------------------------------------------------------------------+
// | MCMS: a PHP Content Management System for creating accessible sites. |
// | Copyright (C) 2006  Silvio Moioli                                    |
// |                                                                      |
// | This program is free software; you can redistribute it and/or modify |
// | it under the terms of the GNU General Public License as published by |
// | the Free Software Foundation; either version 2 of the License, or    |
// | (at your option) any later version.                                  |
// |                                                                      |
// | This program is distributed in the hope that it will be useful,      |
// | but WITHOUT ANY WARRANTY; without even the implied warranty of       |
// | MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the        |
// | GNU General Public License for more details.                         |
// |                                                                      |
// | You should have received a copy of the GNU General Public License    |
// | along with this program; if not, write to the Free Software          |
// | Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307 |
// +----------------------------------------------------------------------+
// | Authors: Silvio Moioli <silvio at moioli dot net> www.moioli.net     |
// +----------------------------------------------------------------------+
//
//$Id:

/** Importa la classe di base per l"interfaccia utente (autore) */
require_once $_SERVER["DOCUMENT_ROOT"]."/admin/lib/view/AdminPage.php";
/** Importa la libreria per semplificare l"aggiunta di tag XML */
require_once $_SERVER["DOCUMENT_ROOT"]."/admin/lib/view/Tagger.php";

/**
 * Rappresenta la pagina iniziale di modifica di un sito. Da qui si possono
 * modificare i componenti aggiuntivi selezionati oppure accedere alle pagine
 * di modifica/cancellazione di articoli, notizie, sezioni e homepage.
 * 
 * @package  MCMS
 * @version  2
 * @author   Silvio Moioli <silvio at moioli dot net>
 */
class AdminManageSite extends AdminPage
{
    /** @var Engine l'oggetto per la comunicazione al Database */
    var $engine = null;
    /** @var Author l'autore che accede a questa pagina */
    var $author = null;
    /** @var Site il sito da modificare */
    var $site = null;
    
    /**
     * Costruttore di default
     *
     * @param Engine $engine l'oggetto per la comunicazione al Database
     * @param Author $author l'autore che accede a questa pagina
     * @param Site $site il sito da modificare
     * @see AdminPage
     */
    function AdminManageSite($author, $site)
    {
        parent::AdminPage();
        $this->author=$author;
        $this->site=$site;
        $this->engine=$author->getEngine();
    }
    
    /**
     * Ritorna il titolo (in XHTML) di questa pagina.
     *
     * @return string una stringa XHTML rappresentante il titolo della pagina
     * @see Compilable
     */
    function getTitle()
    {
        $authorID = $this->author->getID();
        
        $title = a("do.php?goTo=AdminMain&amp;authorID=$authorID",
            "Il Progettista")." > ".$this->site->getShortURL();
        
        return $title;
    }
    
    /**
     * Ritorna un array di stringhe XHTML relative al menu (barra di navigazione)
     * di questa pagina.
     *
     * @return array vettore di stringhe XHTML rappresentante il menu della pagina
     * @see Compilable
     */
    function getMenuEntries()
    {
        $authorID = $this->author->getID();
        $siteID = $this->site->getID();
    
        $menuEntries = array(p(a("do.php?goTo=AdminMain&amp;".
            "authorID=$authorID", "Torna alla pagina principale del Progettista").
            br().a("../index$siteID.html", "Vedi il tuo sito!")));
        
        return $menuEntries;
    }
    
    /**
     * Ritorna il contenuto (XHTML) del corpo di questa pagina.
     *
     * @return string la stringa XHTML rappresentante il corpo della pagina
     * @see Compilable
     */
    function getContents()
    {
        $authorID = $this->author->getID();
        $siteID = $this->site->getID();
        
        $contents = h1("Gestisci il sito ".a("../index$siteID.html",
            $this->site->getShortURL())).
            p("Il tuo sito &egrave; gi&agrave; online ".
            a("../index$siteID.html","qui").br().
            "Da questa pagina, puoi gestire il contenuto del tuo sito.").
            h2("Notizie (in prima pagina)").
            unorderedList(array(
                "Vuoi ".a("do.php?authorID=$authorID&amp;siteID=$siteID&amp;".
                "goTo=AdminEditNews&amp;mode=new","aggiungere la notizia del giorno?"),
                "Vuoi ".a("do.php?goTo=AdminListNews&amp;authorID=$authorID&amp;".
                "siteID=$siteID",
                "modificare o cancellare le notizie pi&ugrave; vecchie?"),
            )).
            h2("Articoli (nel resto del sito)").
            unorderedList(array(
                "Vuoi ".a("do.php?goTo=AdminEditArticle&amp;".
                "authorID=$authorID&amp;siteID=$siteID&amp;mode=new",
                "aggiungere un nuovo articolo?"),
                "Vuoi ".a("do.php?goTo=AdminListArticles&amp;".
                "authorID=$authorID&amp;siteID=$siteID",
                "modificare o cancellare un vecchio articolo?")
            ));
            
        $homepage = $this->site->getHomepage();
        $homepageAuthor = $homepage->getAuthor();
        $homepageAuthorID = $homepageAuthor->getID();
        if ($this->author->getID() == $homepageAuthorID){
            //sezioni
            $contents .= h2("Sezioni (contenitori di articoli)").
                unorderedList(array(
                    "Vuoi ".a("do.php?goTo=AdminEditCategory&amp;".
                    "authorID=$authorID&amp;siteID=$siteID&amp;mode=new",
                    "una nuova sezione per i tuoi articoli?"),
                    "Vuoi ".a("do.php?goTo=AdminListCategories&amp;".
                    "authorID=$authorID&amp;siteID=$siteID&amp;mode=edit",
                    "modificare o cancellare le sezioni?")
                ));
            //homepage
            $contents .= h2("Homepage").
                unorderedList(array("Vuoi ".
                a("do.php?goTo=AdminEditHomepage&amp;authorID=$authorID".
                "&amp;siteID=$siteID","ritoccare la pagina iniziale del sito?")));
            //componenti aggiuntivi
            $contents .= h2("Componenti aggiuntivi del sito");
            $components = $this->engine->getComponents();
            $componentNames = array();
            foreach($components as $i) {
                $componentNames[] = get_class($i);
            }
            $activated = $this->site->getComponents();
            $activatedNames = array();
            foreach($activated as $i) {
                $activatedNames[] = get_class($i);
            }
            //Creo la lista di checkboxes
            $cont = 0;
            $checks = array();
            foreach($components as $i) {
                $activated = false;
                //Se  gi attivato, segno la checkbox
                if (in_array($componentNames[$cont], $activatedNames)) {
                    $activated = true;
                }
                $checks []= checkbox("component".$componentNames[$cont],$activated).
                    $i->getName();
                $cont++;
            }
            $formContents = unorderedList($checks).submit("Cambia");
            $contents .= form("do.php?goTo=AdminManageSite&amp;".
                "siteID=$siteID&amp;authorID=$authorID&amp;action=editComponents",
                "POST",$formContents);
        }
        else {
            $contents .= h2("Sezioni (contenitori di articoli)").
                p("Non puoi modificare le sezioni degli articoli se non sei il ".
                b("fondatore")." del sito.").
                h2("Homepage").p("Non puoi modificare la pagina iniziale se non
                sei il ".b("fondatore")." del sito.").
                h2("Componenti aggiuntivi del sito").p("Non puoi modificarli se
                non sei il ".b("fondatore")." del sito.");
        }
        
        return $contents;
    }
}
?>
