<?php
/* vim: set expandtab tabstop=4 shiftwidth=4: */
// +----------------------------------------------------------------------+
// | MCMS: a PHP Content Management System for creating accessible sites. |
// | Copyright (C) 2006  Silvio Moioli                                    |
// |                                                                      |
// | This program is free software; you can redistribute it and/or modify |
// | it under the terms of the GNU General Public License as published by |
// | the Free Software Foundation; either version 2 of the License, or    |
// | (at your option) any later version.                                  |
// |                                                                      |
// | This program is distributed in the hope that it will be useful,      |
// | but WITHOUT ANY WARRANTY; without even the implied warranty of       |
// | MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the        |
// | GNU General Public License for more details.                         |
// |                                                                      |
// | You should have received a copy of the GNU General Public License    |
// | along with this program; if not, write to the Free Software          |
// | Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307 |
// +----------------------------------------------------------------------+
// | Authors: Silvio Moioli <silvio at moioli dot net> www.moioli.net     |
// +----------------------------------------------------------------------+
//
//$Id:

/**
 * Classe astratta che rappresenta una pagina XHTML.
 * Ogni sottoclasse deve implementare tutti i suoi metodi e potr
 * essere usata per generare il codice relativo tramite 
 * un oggetto Compiler.
 *
 * @package  MCMS
 * @version  2
 * @author   Silvio Moioli <silvio at moioli dot net>
 */
/*abstract*/ class Compilable extends PEAR
{
    /**
     * Costruttore di default
     *
     */
    function Compilable()
    {
    }
    
    /**
     * Questo metodo  "astratto" pertanto dovrebbe essere implementato da
     * tutte le classi che estendono questa classe.
     *
     * Ritorna il titolo (in XHTML) di questa pagina.
     *
     * @return string una stringa XHTML rappresentante il titolo della pagina
     */
    /*abstract*/function getTitle()
    {
        return PEAR_raiseError("Unimplemented abstract method called!");
    }
    
    /**
     * Questo metodo  "astratto" pertanto dovrebbe essere implementato da
     * tutte le classi che estendono questa classe.
     *
     * Ritorna una breve descrizione (solo testo) di questa pagina.
     *
     * @return string una stringa rappresentante la descrizione della pagina
     */
    /*abstract*/function getDescription()
    {
        return PEAR_raiseError("Unimplemented abstract method called!");
    }
    
    /**
     * Questo metodo  "astratto" pertanto dovrebbe essere implementato da
     * tutte le classi che estendono questa classe.
     *
     * Ritorna un array di stringhe XHTML relative al menu (barra di navigazione)
     * di questa pagina.
     *
     * @return array vettore di stringhe XHTML rappresentante il menu della pagina
     */
    /*abstract*/function getMenuEntries()
    {
        return PEAR_raiseError("Unimplemented abstract method called!");
    }
    
    /**
     * Questo metodo  "astratto" pertanto dovrebbe essere implementato da
     * tutte le classi che estendono questa classe.
     *
     * Ritorna il contenuto (XHTML) del corpo di questa pagina.
     *
     * @return string la stringa XHTML rappresentante il corpo della pagina
     */
    /*abstract*/function getContents()
    {
        return PEAR_raiseError("Unimplemented abstract method called!");
    }

    /**
     * Questo metodo  "astratto" pertanto dovrebbe essere implementato da
     * tutte le classi che estendono questa classe.
     *
     * Ritorna una stringa di parole chiave (solo testo, separate da virgole)
     * di questa pagina.
     *
     * @return string la stringa rappresentante le parole chiave della pagina
     */
    /*abstract*/function getKeywords()
    {
        return PEAR_raiseError("Unimplemented abstract method called!");
    }
    
    /**
     * Questo metodo  "astratto" pertanto dovrebbe essere implementato da
     * tutte le classi che estendono questa classe.
     *
     * Ritorna il nome del file template per questa pagina (pathname relativo
     * a $_SERVER["DOCUMENT_ROOT"]/admin/include/smarty/templates/)
     *
     * @return string il nome del file del template
     */
    /*abstract*/function getTemplate()
    {
        return PEAR_raiseError("Unimplemented abstract method called!");
    }
    
    /**
     * Questo metodo  "astratto" pertanto dovrebbe essere implementato da
     * tutte le classi che estendono questa classe.
     *
     * Ritorna un array di plugin di MCMS (sottoclassi di Component) che
     * si applicano a questa pagina.
     *
     * @return array un vettore di Component che si applicano a questa pagina
     */
    /*abstract*/function getComponents()
    {
        return PEAR_raiseError("Unimplemented abstract method called!");
    }
}
?>
