<?php
/* vim: set expandtab tabstop=4 shiftwidth=4: */
// +----------------------------------------------------------------------+
// | MCMS: a PHP Content Management System for creating accessible sites. |
// | Copyright (C) 2006  Silvio Moioli                                    |
// |                                                                      |
// | This program is free software; you can redistribute it and/or modify |
// | it under the terms of the GNU General Public License as published by |
// | the Free Software Foundation; either version 2 of the License, or    |
// | (at your option) any later version.                                  |
// |                                                                      |
// | This program is distributed in the hope that it will be useful,      |
// | but WITHOUT ANY WARRANTY; without even the implied warranty of       |
// | MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the        |
// | GNU General Public License for more details.                         |
// |                                                                      |
// | You should have received a copy of the GNU General Public License    |
// | along with this program; if not, write to the Free Software          |
// | Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307 |
// +----------------------------------------------------------------------+
// | Authors: Silvio Moioli <silvio at moioli dot net> www.moioli.net     |
// +----------------------------------------------------------------------+
//
//$Id:

/** Carica la classe base di MCMS per l'interfacciamento al Database */
require_once $_SERVER["DOCUMENT_ROOT"]."/admin/lib/model/Engine.php";
/** Carica la classe dei siti di MCMS */
require_once $_SERVER["DOCUMENT_ROOT"]."/admin/lib/model/Site.php";
/** Carica il gestore dei template (Smarty) */
require_once $_SERVER["DOCUMENT_ROOT"]."/admin/include/smarty/libs/Smarty.class.php";
/** Carica la libreria per semplificare l'aggiunta di tag XML */
require_once $_SERVER["DOCUMENT_ROOT"]."/admin/lib/view/Tagger.php";
/** Carica le pagine della vista User */
require_once $_SERVER["DOCUMENT_ROOT"]."/admin/lib/view/alluser.inc";

/**
 * Compilatore di interfacce XHTML. Crea/aggiorna i file
 * XHTML di cui  composto un sito.
 * 
 * @package  MCMS
 * @version  2
 * @author   Silvio Moioli <silvio at moioli dot net>
 *
 */
class Compiler extends PEAR
{
    /** @var Smarty l'oggetto per la gestione dei template */
    var $smarty = null;
    /** @var string il nome del template da usare per questo sito */
    var $templateFileName = null;
    /** @var string il nome della directory dove creare i file XHTML */
    var $compilingDir = null;
    /** @var il path dell'utility Tidy */
    var $tidy = null;
    /** @var string il nome dell'eseguibile di Tidy per Windows */
    var $tidyWindows = "tidy.exe";
    /** @var string il nome dell'eseguibile di Tidy per Linux */
    var $tidyLinux = "tidy";
    /** @var bool Tidy  supportato? */
    var $tidyEnabled = false;
    /** @var string il path del log degli errori di Tidy */
    var $tidyLog = null;
    
    /**
     * Costruttore di default.
     *
     * Costruisce un compilatore di interfacce XHTML per il sito specificato.
     */
    function Compiler()
    {
        $this->smarty = new Smarty();
        $this->compilingDir = $_SERVER["DOCUMENT_ROOT"]."/";
        $this->templateFileName = $_SERVER["DOCUMENT_ROOT"]."/admin/include/smarty/".
        "templates/userTemplate.tpl";
        $tidyDir = $_SERVER["DOCUMENT_ROOT"]."/admin/include/tidy/";
        $this->tidyLog = $tidyDir."error.log";
        
        if (strtoupper(substr(PHP_OS, 0, 3)) == "WIN"){
            $this->tidyEnabled = false;
            $tidy = $tidyDir.$this->tidyWindows;
        }
        if (strtoupper(substr(PHP_OS, 0, 3)) == "LIN"){
            $this->tidyEnabled = true;
            $this->tidy = $tidyDir.$this->tidyLinux;
        }
    }
    
   /**
    * Visualizza direttamente la pagina passata.
    *
    * @param Compilable $page la pagina da visualizzare
    * @see Compilable
    */
    function display($page)
    {
        //Assegno le variabili a Smarty
        $this->smarty->assign('title',$page->getTitle());
        $this->smarty->assign('menuEntries',$page->getMenuEntries());
        $this->smarty->assign('contents',$page->getContents());
        $this->smarty->assign('keywords',$page->getKeywords());
        $this->smarty->assign('description',$page->getDescription());
        
        //Visualizzo la pagina
        $this->smarty->display($page->getTemplate());
    }

   /**
    * Salva la pagina su file.
    *
    * @param Savable $page la pagina da salvare
    * @see Compilable
    */
    function save($page)
    {
        //Inizio del caching
        ob_start();
        $this->smarty = $this->smarty;
        
        $contents = $page->getContents();
        $menuEntries = $page->getMenuEntries();
        $title = $page->getTitle();
        $description = $page->getDescription();
        $keywords = $page->getKeywords();
        
        //Applico i componenti opzionali, se possibile.
        if (is_a($page,"UserPage")) {
            $components = $page->getComponents();
            foreach ($components as $i) {
                $i->applyComponent($contents, $menuEntries, $title, $description,
                    $page->getSite());
            }
        }
        
        //Assegno le variabili a Smarty
        $this->smarty->assign('title',$title);
        $this->smarty->assign('menuEntries',$menuEntries);
        $this->smarty->assign('contents',$contents);
        $this->smarty->assign('keywords',$keywords);
        $this->smarty->assign('description',$description);
        
        //Compilo la pagina
        $this->smarty->display($this->templateFileName);
    
        //Ritorno come stringa e ripulisco
        $result = ob_get_contents();
        ob_end_clean();
        
        $this->fileSave($page->getFileName(), $result, true);
    }
    
    /**
     * Salva su file i contenuti XHTML specificati, se indicato tramite Tidy.
     *
     * @param string $fileName il nome del file su cui salvare (deve essere
     * scrivibile)
     * @param string il contenuto XHTML del file
     * @param bool $useTidy true se utilizzare Tidy (se possibile)
     */
    function fileSave($fileName, $contents, $useTidy=true)
    {
        //Se  abilitato, usa Tidy
        if ($this->tidyEnabled && $useTidy == true){
/*            $fp = fopen($this->tidyLog, 'a');
            fwrite($fp, "Processing: $fileName\n");
            fclose($fp);*/
            $contents = $this->runExternal($this->tidy." -m --force-output true ".
                "--indent true --indent-spaces 4 --wrap 160 ".
                "--char-encoding latin1 --output-xhtml true",$contents);
        }
        $fullName = $this->compilingDir."/".$fileName;
        $dir = dirname($fullName);
        if (is_dir($dir) == false){
            mkdir($dir);
        }
        $fp = fopen($fullName, 'w');
        fwrite($fp, $contents);
        fclose($fp);
    }
    
   /**
    * Salva su file tutti gli elementi un sito.
    *
    * @param Site $site il sito da salvare
    */
    function saveAll($site)
    {
        $this->save(new UserHomepage($site));
        $this->save(new UserNews($site));
        $articles = $site->getArticles();
        foreach ($articles as $i) {
            $this->save(new UserArticle($site, $i));
        }
        $categories = $site->getCategories();
        foreach ($categories as $i) {
            $this->save(new UserCategory($site, $i));
        }
        
        $this->saveComponents($site);
    }
    
    /**
     * Permette a tutti i plugin attivati sul sito specificato
     * di salvare i loro file aggiuntivi.
     * 
     * @param Site $site il sito di cui salvare i file dei plugin
     * @see Component
     */
    function saveComponents($site)
    {
        $components = $site->getComponents();
        foreach ($components as $i) {
            $i->saveFiles($site, $this);
        }
    }
       
   /**
    * Cancella il file corrispondente a una pagina di un sito (se esiste).
    *
    * @param Savable $savable l'oggetto Savable da eliminare
    */
    function remove($savable){
        $fname = $this->compilingDir.$savable->getFileName();
        if (file_exists($fname)){
            unlink($fname);
        }
    }
   
   /**
    * Elimina tutti gli elementi di questo sito (cancellando i file relativi).
    */
    function removeAll($site)
    {
        $this->remove(new UserHomepage($site));
        $this->remove(new UserNews($site));
        $this->remove(new UserNews($site));
        $articles = $site->getArticles();
        foreach ($articles as $i) {
            $this->remove(new UserArticle($site, $i));
        }
        $categories = $site->getCategories();
        foreach ($categories as $i) {
            $this->remove(new UserCategory($site, $i));
        }
        //TODO: removeComponents...
    }
    
    /**
     * Filtra la stringa specificata in stdin attraverso un programma
     * esterno.
     *
     * @param string command il comando da eseguire
     * @param string stdin la stringa da filtrare
     * @return string la stringa filtrata
     */
    function runExternal($command,$stdin) {
        $descriptorSpec = array(0 => array("pipe", "r"),
                                1 => array('pipe', 'w'),
                                2 => array('pipe', 'w'));
        $process = proc_open($command, $descriptorSpec, $pipes);
        $txOff = 0; $txLen = strlen($stdin);
        $stdout = ''; $stdoutDone = FALSE;
        $stderr = ''; $stderrDone = FALSE;
        stream_set_blocking($pipes[0], 0); // Make stdin/stdout/stderr non-blocking
        stream_set_blocking($pipes[1], 0);
        stream_set_blocking($pipes[2], 0);
        if ($txLen == 0) fclose($pipes[0]);
        while (TRUE) {
            $rx = array(); // The program's stdout/stderr
            if (!$stdoutDone) $rx[] = $pipes[1];
            if (!$stderrDone) $rx[] = $pipes[2];
            $tx = array(); // The program's stdin
            if ($txOff < $txLen) $tx[] = $pipes[0];
                stream_select($rx, $tx, $ex = NULL, NULL, NULL); // Block til r/w possible
                if (!empty($tx)) {
                    $txRet = fwrite($pipes[0], substr($stdin, $txOff, 8192));
                    if ($txRet !== FALSE) $txOff += $txRet;
                    if ($txOff >= $txLen) fclose($pipes[0]);
                }
                foreach ($rx as $r) {
                    if ($r == $pipes[1]) {
                        $stdout .= fread($pipes[1], 8192);
                        if (feof($pipes[1])) {
                            fclose($pipes[1]);
                            $stdoutDone = TRUE;
                        }
                    }
                    else if ($r == $pipes[2]) {
                        $stderr .= fread($pipes[2], 8192);
                        if (feof($pipes[2])) {
                            fclose($pipes[2]);
                            $stderrDone = TRUE;
                        }
                    }
                }
                if (!is_resource($process)) break;
                if ($txOff >= $txLen && $stdoutDone && $stderrDone) break;
        }
        $returnValue = proc_close($process);
        return $stdout;
    }
}

?>
