<?php
/* vim: set expandtab tabstop=4 shiftwidth=4: */
// +----------------------------------------------------------------------+
// | MCMS: a PHP Content Management System for creating accessible sites. |
// | Copyright (C) 2006  Silvio Moioli                                    |
// |                                                                      |
// | This program is free software; you can redistribute it and/or modify |
// | it under the terms of the GNU General Public License as published by |
// | the Free Software Foundation; either version 2 of the License, or    |
// | (at your option) any later version.                                  |
// |                                                                      |
// | This program is distributed in the hope that it will be useful,      |
// | but WITHOUT ANY WARRANTY; without even the implied warranty of       |
// | MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the        |
// | GNU General Public License for more details.                         |
// |                                                                      |
// | You should have received a copy of the GNU General Public License    |
// | along with this program; if not, write to the Free Software          |
// | Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307 |
// +----------------------------------------------------------------------+
// | Authors: Silvio Moioli <silvio at moioli dot net> www.moioli.net     |
// +----------------------------------------------------------------------+
//
//$Id:

/**
 * Raccolta di funzioni per l'input semplificato di codice XML.
 *
 * @package  MCMS
 * @version  2
 * @author   Silvio Moioli <silvio at moioli dot net>
 */

function tag($tag, $string = "", $attributes = array()){
    $attributesString="";
    if (empty($attributes) == false){
        $attributesString=" ";
        foreach ($attributes as $key => $value){
            $attributesString.=$key."=\"".$value."\" ";
        }
    }
    $result="";
    if ($string == ""){
        $result = "<".$tag.$attributesString." />";
    }
    else{
        $result = "<".$tag.$attributesString.">".$string."</".$tag.">";
    }
    return $result;
}

function b($string){
    return tag("strong",$string,array());
}

function p($string){
    return tag("p",$string,array());
}

function h1($string, $id = ''){
    $attributes = array();
    if ($id != ''){
        $attributes['id']=$id;
    }
    return tag("h1",$string,$attributes);
}
function h2($string, $id = ''){
    $attributes = array();
    if ($id != ''){
        $attributes['id']=$id;
    }
    return tag("h2",$string,$attributes);
}
function h3($string, $id = ''){
    $attributes = array();
    if ($id != ''){
        $attributes['id']=$id;
    }
    return tag("h3",$string,$attributes);
}

function ul($string){
    if ($string!=""){
        return tag("ul",$string,array());
    }
    else{
        return "";
    }
}
function ol($string){
    if ($string!=""){
        return tag("ol",$string,array());
    }
    else{
        return "";
    }
}
function li($string){
    return tag("li",$string,array());
}
function unorderedList($elements){
    $elementsString="";
    foreach ($elements as $i){
        $elementsString.=li($i);
    }
    return ul($elementsString);
}

function a($where,$anchor){
    return tag("a",$anchor,array("href" => $where));
}

function form($action, $method, $string){
    $attribs = array();
    $attribs["action"]=$action;
    $attribs["method"]=$method;
    return tag("form", $string, $attribs);
}

function input($type, $name, $value=""){
    $attribs = array();
    $attribs["type"]=$type;
    $attribs["name"]=$name;
    $attribs["value"]=$value;
    return tag("input","",$attribs);
}

function submit($label = "Invia"){
    return tag("input","",array("type" => "submit", "value" => $label));
}

function br(){
    return tag("br","","");
}

function checkbox($name, $checked){
    $attribs = array();
    $attribs["type"]="checkbox";
    $attribs["name"]=$name;
    if ($checked == true){
        $attribs["checked"]="checked";
    }
    return tag("input","",$attribs);
}

function option($value, $selected, $string){
    $attribs = array();
    $attribs["value"]=$value;
    if ($selected == true){
        $attribs["selected"]="selected";
    }
    return tag("option", $string, $attribs);
}

function select($name, $string){
    $attribs = array();
    $attribs["name"]=$name;
    return tag("select", $string, $attribs);
}

/**
* Aggiunge ai contenuti della pagina un componente per l'editing dell'HTML.
* Pu essere FCKEditor o, se richiesto, una semplice input HTML.
*
* @param $contentsValue string i contenuti della pagina
*/
function HTMLEditor($contentsValue, $javascript)
{
    $htmlContents = htmlspecialchars($contentsValue, ENT_QUOTES);
    $result = "";
    
    if ($javascript == true){
        //FCKEditor
        $oFCKeditor = new FCKeditor('contents') ;
        $oFCKeditor->BasePath = "/admin/include/fckeditor/";
        if ($oFCKeditor->IsCompatible()== false){
            $result .= b("Il tuo browser non &egrave; supportato da FCKEditor.");
        }
        else{
            $oFCKeditor->Value = $contentsValue;
            $oFCKeditor->Height = '500' ;
            $result .= $oFCKeditor->CreateHtml() ;
            $result .= '<p><a href="'.$_SERVER['PHP_SELF'].'?javascript=off&amp;';

            //Ricopia le variabili GET se presenti
            if (isset($_GET)){
                foreach ($_GET as $key => $value) {
                    if ($key != "javascript"){
                        $result .= "$key=$value&amp;";
                    }
                }
            }
        }
        $result .= '">Versione senza javascript</a></p>';
    }
    else{
        //Piccolo hack per l'input dell'HTML direttamente
        $result .= '<p><textarea cols="80" rows="100"
            name="contents">'.htmlspecialchars($contentsValue,
            ENT_QUOTES).'</textarea></p>';

        $result .= '<p><a href="'.$_SERVER['PHP_SELF'].'?javascript=on&amp;';
        //Ricopia le variabili GET se presenti
        if (isset($_GET)){
            foreach ($_GET as $key => $value) {
                if ($key != "javascript"){
                    $result .= "$key=$value&amp;";
                }
            }
        }
        $result .= '">Versione con javascript</a></p>';
    }
    
    return $result;
}
    
/**
* Ritorna una stringa XHTML con la "firma"
* dell'autore. Se non &egrave; specificato l'autore,
* si tenter&agrave; di recuperarlo dall'autore corrente.
*
* @param $author Author l'autore di cui si cerca la firma
*/
function getAuthorSignature($author)
{   
    $result = "";
    $name = $author->getName();
    $nick = $author->getNick();
    $surname = $author->getSurname();
    $email = $author->getEmail();
    if ($name != null && $name != ""){
        $result .= $name;
    }
    if ($surname != null && $surname != ""){
        $result .= " ".$surname;
    }
    if ($email != null && $email  != ""){
        $email = str_replace("@", " at ", $email);
        $email = str_replace(".", " punto ", $email);

        $result .= " (";
        if ($nick != null && $nick != ""){
            $result .= "<em>&quot;".$nick."&quot;</em>, ";
        }
        
        $result .= $email.")";
    }
    
    return $result;
}
?>
