<?php
/* vim: set expandtab tabstop=4 shiftwidth=4: */
// +----------------------------------------------------------------------+
// | MCMS: a PHP Content Management System for creating accessible sites. |
// | Copyright (C) 2006  Silvio Moioli                                    |
// |                                                                      |
// | This program is free software; you can redistribute it and/or modify |
// | it under the terms of the GNU General Public License as published by |
// | the Free Software Foundation; either version 2 of the License, or    |
// | (at your option) any later version.                                  |
// |                                                                      |
// | This program is distributed in the hope that it will be useful,      |
// | but WITHOUT ANY WARRANTY; without even the implied warranty of       |
// | MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the        |
// | GNU General Public License for more details.                         |
// |                                                                      |
// | You should have received a copy of the GNU General Public License    |
// | along with this program; if not, write to the Free Software          |
// | Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307 |
// +----------------------------------------------------------------------+
// | Authors: Silvio Moioli <silvio at moioli dot net> www.moioli.net     |
// +----------------------------------------------------------------------+
//
//$Id:

require_once $_SERVER["DOCUMENT_ROOT"]."/admin/lib/view/UserPage.php";
require_once $_SERVER["DOCUMENT_ROOT"]."/admin/lib/view/Tagger.php";

/**
 * Rappresenta un articolo di un sito.
 * 
 * @package  MCMS
 * @version  2
 * @author   Silvio Moioli <silvio at moioli dot net>
 */
class UserArticle extends UserPage
{
    /** @var Homepage l'oggetto corrispondente alla home del sito */
    var $homepage = null;
    /** @var Article l'oggetto corrispondente a questa pagina */
    var $article = null;
          
    /**
     * Costruttore standard
     *
     * @param Site $site il sito a cui questa pagina appartiene
     * @param Article $article l'oggetto corrispondente a questa pagina
     * @see AdminPage
     */
    function UserArticle($site, $article)
    {
        parent::UserPage($site);
        $this->article = $article;
        $this->homepage = $site->getHomepage();
    }
    
    /**
     * Ritorna il titolo (in XHTML) di questa pagina.
     *
     * @return string una stringa XHTML rappresentante il titolo della pagina
     * @see Compilable
     */
    function getTitle()
    {
        $category = $this->article->getCategory();
        
        return a(UserHomepage::staticGetFileName($this->site),
            $this->homepage->getTitle())." > ".
            a(UserCategory::staticGetFileName($category),
            $category->getName()).
            " > ".$this->article->getTitle();
    }
    
    /**
     * Ritorna una breve descrizione (solo testo) di questa pagina.
     *
     * @return string una stringa rappresentante la descrizione della pagina
     * @see Compilable
     */
    function getDescription()
    {
        return $this->article->getDescription();
    }
    
    /**
     * Ritorna un array di stringhe XHTML relative al menu (barra di navigazione)
     * di questa pagina.
     *
     * @return array vettore di stringhe XHTML rappresentante il menu della pagina
     * @see Compilable
     */
    function getMenuEntries()
    {
        $siteID = $this->site->getID();
        $category = $this->article->getCategory();
        
        //Crea il menu per gli articoli correlati, quelli della
        //stessa categoria e il ritorno alla home
        $menuEntries = array(p("Torna alla ".a(
            UserHomepage::staticGetFileName($this->site),"homepage")));
    
        //Se ci sono articoli correlati, li inserisco nel menu
        if ($this->article->getCorrelatedArticlesCount() >  0) {
            $correlated = $this->article->getCorrelatedArticles();
            $listEntries = array();
            foreach ($correlated as $i) {
                $articleTitle = $i->getTitle();
                $listEntries []= a(UserArticle::staticGetFileName($i),
                    $articleTitle).";";
            }
            $menuEntries[] = p("Articoli correlati:".br().unorderedList($listEntries));
        }
        
        //Se ci sono altri articoli nella stessa categoria, li inserisco nel menu
        if ($this->article->getNeighbourArticlesCount() >0) {
            $listEntries = array();
            $neighbours = $this->article->getNeighbourArticles();
            foreach ($neighbours as $i) {
                $articleTitle = $i->getTitle();
                $listEntries[] = a(UserArticle::staticGetFileName($i),
                    $articleTitle).";";
            }
            $menuEntries[] = p("Articoli della stessa categoria ".
                $category->getName().br().unorderedList($listEntries));
        }
        return $menuEntries;
    }
    
    /**
     * Ritorna il contenuto (XHTML) del corpo di questa pagina.
     *
     * @return string la stringa XHTML rappresentante il corpo della pagina
     * @see Compilable
     */
    function getContents()
    {
        $site = $this->site;
        $articleID = $this->article->getID();
        $siteID = $site->getID();
        $homepage = $site->getHomepage();
    
        //Crea il contenuto della pagina
        $author = $this->article->getAuthor();
        $contents = $this->article->getContents().$this->article->getDate().
            ", Articolo di: ".
            getAuthorSignature($this->article->getAuthor());
            
        return $contents;
    }
    
    /**
     * Ritorna una stringa di parole chiave (solo testo, separate da virgole)
     * di questa pagina.
     *
     * @return string la stringa rappresentante le parole chiave della pagina
     * @see Compilable
     */
    function getKeywords()
    {
        return $this->article->getDescription();
    }
    
    /**
     * Ritorna il nome del file in cui questa pagina deve essere salvata.
     *
     * @return string il nome del file
     * @see Savable
     */
    function getFileName()
    {
        return $this->staticGetFileName($this->article);
    }
    
    /**
     * Versione statica del metodo precedente: ritorna il nome del 
     * file in cui questa pagina deve essere salvata.
     *
     * @return string il nome del file
     * @see Savable
     */
    function staticGetFileName($article)
    {
        $category = $article->getCategory();
        $catName = UserPage::fileName($category->getName()).'___'.$category->getID();
        $artName = UserPage::fileName($article->getTitle()).'___'.$article->getID();
        return "/$catName/$artName.html";
    }
        
    /**
     * Ritorna il nome del file in cui questa pagina deve essere salvata
     * (versione precedente).
     *
     * @return string il nome del file
     * @see Savable
     */
    function getOldFileName()
    {
        return "art".$this->article->getID().".html";
    }
}
?>
