<?php
/* vim: set expandtab tabstop=4 shiftwidth=4: */
// +----------------------------------------------------------------------+
// | MCMS: a PHP Content Management System for creating accessible sites. |
// | Copyright (C) 2006  Silvio Moioli                                    |
// |                                                                      |
// | This program is free software; you can redistribute it and/or modify |
// | it under the terms of the GNU General Public License as published by |
// | the Free Software Foundation; either version 2 of the License, or    |
// | (at your option) any later version.                                  |
// |                                                                      |
// | This program is distributed in the hope that it will be useful,      |
// | but WITHOUT ANY WARRANTY; without even the implied warranty of       |
// | MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the        |
// | GNU General Public License for more details.                         |
// |                                                                      |
// | You should have received a copy of the GNU General Public License    |
// | along with this program; if not, write to the Free Software          |
// | Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307 |
// +----------------------------------------------------------------------+
// | Authors: Silvio Moioli <silvio at moioli dot net> www.moioli.net     |
// +----------------------------------------------------------------------+
//
//$Id:

require_once $_SERVER["DOCUMENT_ROOT"]."/admin/lib/view/UserPage.php";
require_once $_SERVER["DOCUMENT_ROOT"]."/admin/lib/view/Tagger.php";

/**
 * Rappresenta un articolo di un sito.
 * 
 * @package  MCMS
 * @version  2
 * @author   Silvio Moioli <silvio at moioli dot net>
 */
class UserCategory extends UserPage
{
    /** @var Category l'oggetto corrispondente a questa pagina */
    var $category = null;
          
    /**
     * Costruttore standard
     *
     * @param Site $site il sito a cui questa pagina appartiene
     * @param Category $category l'oggetto corrispondente a questa pagina
     * @see AdminPage
     */
    function UserCategory($site, $category)
    {
        parent::UserPage($site);
        $this->category = $category;
    }
    
    /**
     * Ritorna il titolo (in XHTML) di questa pagina.
     *
     * @return string una stringa XHTML rappresentante il titolo della pagina
     * @see Compilable
     */
    function getTitle()
    {
        $home = $this->site->getHomepage();
        
        return a(UserHomepage::staticGetFileName($this->site),$home->getTitle())." > ".
            $this->category->getName();
    }
    
    /**
     * Ritorna una breve descrizione (solo testo) di questa pagina.
     *
     * @return string una stringa rappresentante la descrizione della pagina
     * @see Compilable
     */
    function getDescription()
    {
        return $this->category->getDescription();
    }
    
    /**
     * Ritorna un array di stringhe XHTML relative al menu (barra di navigazione)
     * di questa pagina.
     *
     * @return array vettore di stringhe XHTML rappresentante il menu della pagina
     * @see Compilable
     */
    function getMenuEntries()
    {
        $siteID = $this->site->getID();
        
        $menuEntries = array(p("Torna alla ".a(
            UserHomepage::staticGetFileName($this->site),"homepage")));
        
        $listElements = array();
        $articles = $this->category->getArticles();
        foreach ($articles as $i) {
            $articleID = $i->getID();
            $articleTitle = $i->getTitle();
            $listElements[] = a(UserArticle::staticGetFileName($i),
                $articleTitle);
        }
        $menuEntries []= p("Articoli di questa sezione:".br().
            unorderedList($listElements));
            
        return $menuEntries;
    }
    
    /**
     * Ritorna il contenuto (XHTML) del corpo di questa pagina.
     *
     * @return string la stringa XHTML rappresentante il corpo della pagina
     * @see Compilable
     */
    function getContents()
    {  
        //Crea il contenuto della pagina
        $contents = p($this->category->getDescription());
        $articles = $this->category->getArticles();
        foreach ($articles as $i) {
            $author = $i->getAuthor();
            $articleID = $i->getID();
            $articleTitle = $i->getTitle();
            $contents .= h1(a(UserArticle::staticGetFileName($i),$articleTitle));
            $contents .= p($i->getDescription());
            $contents .= getAuthorSignature($i->getAuthor());
        }
            
        return $contents;
    }
    
    /**
     * Ritorna una stringa di parole chiave (solo testo, separate da virgole)
     * di questa pagina.
     *
     * @return string la stringa rappresentante le parole chiave della pagina
     * @see Compilable
     */
    function getKeywords()
    {
        return $this->category->getDescription();;
    }
    
    /**
     * Ritorna il nome del file in cui questa pagina deve essere salvata.
     *
     * @return string il nome del file
     * @see Savable
     */
    function getFileName()
    {
        return $this->staticGetFileName($this->category);
    }
    
    /**
     * Versione statica del metodo precedente: ritorna il nome del 
     * file in cui questa pagina deve essere salvata.
     *
     * @return string il nome del file
     * @see Savable
     */
    function staticGetFileName($category)
    {
        if (is_a($category,"Category")==false){
//            print var_dump($category);
            print var_dump(debug_backtrace());
        }
        $catName = UserPage::fileName($category->getName()).
            '___'.$category->getID();
        return "/$catName/index.html";
    }
    
    /**
     * Ritorna il nome del file in cui questa pagina deve essere salvata
     * (versione precedente).
     *
     * @return string il nome del file
     * @see Savable
     */
    function getOldFileName()
    {
        return "cat".$this->category->getID().".html";
    }

}
?>
