<?php
/* vim: set expandtab tabstop=4 shiftwidth=4: */
// +----------------------------------------------------------------------+
// | MCMS: a PHP Content Management System for creating accessible sites. |
// | Copyright (C) 2006  Silvio Moioli                                    |
// |                                                                      |
// | This program is free software; you can redistribute it and/or modify |
// | it under the terms of the GNU General Public License as published by |
// | the Free Software Foundation; either version 2 of the License, or    |
// | (at your option) any later version.                                  |
// |                                                                      |
// | This program is distributed in the hope that it will be useful,      |
// | but WITHOUT ANY WARRANTY; without even the implied warranty of       |
// | MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the        |
// | GNU General Public License for more details.                         |
// |                                                                      |
// | You should have received a copy of the GNU General Public License    |
// | along with this program; if not, write to the Free Software          |
// | Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307 |
// +----------------------------------------------------------------------+
// | Authors: Silvio Moioli <silvio at moioli dot net> www.moioli.net     |
// +----------------------------------------------------------------------+
//
//$Id:

require_once $_SERVER["DOCUMENT_ROOT"]."/admin/lib/view/UserPage.php";
require_once $_SERVER["DOCUMENT_ROOT"]."/admin/lib/view/Tagger.php";

/**
 * Rappresenta l'homepage di un sito.
 * 
 * @package  MCMS
 * @version  2
 * @author   Silvio Moioli <silvio at moioli dot net>
 */
class UserHomepage extends UserPage
{
    /** @var Homepage l'oggetto corrispondente a questa pagina */
    var $homepage = null;
          
    /**
     * Costruttore standard
     *
     * @param Site $site il sito a cui questa pagina appartiene
     * @see AdminPage
     */
    function UserHomepage($site)
    {
        parent::UserPage($site);
        $this->homepage=$site->getHomepage();
    }
    
    /**
     * Ritorna il titolo (in XHTML) di questa pagina.
     *
     * @return string una stringa XHTML rappresentante il titolo della pagina
     * @see Compilable
     */
    function getTitle()
    {
        return $this->homepage->getTitle()." - ".$this->homepage->getSlogan();
    }
    
    /**
     * Ritorna una breve descrizione (solo testo) di questa pagina.
     *
     * @return string una stringa rappresentante la descrizione della pagina
     * @see Compilable
     */
    function getDescription()
    {
        return $this->site->getShortURL().' - '.$this->homepage->getSlogan();
    }
    
    /**
     * Ritorna un array di stringhe XHTML relative al menu (barra di navigazione)
     * di questa pagina.
     *
     * @return array vettore di stringhe XHTML rappresentante il menu della pagina
     * @see Compilable
     */
    function getMenuEntries()
    {
        $categories = $this->site->getCategories();
        $listEntries = array();
        foreach ($categories as $i) {
            $id = $i->getID();
            $name = $i->getName();
            $desc = $i->getDescription();
            $entry = a(UserCategory::staticGetFileName($i),
                $name)." - ".$desc;
            $listEntries[]=$entry;
        }
        $menuEntries = array(p("Sezioni del sito:").unorderedList($listEntries));
        return $menuEntries;
    }
    
    /**
     * Ritorna il contenuto (XHTML) del corpo di questa pagina.
     *
     * @return string la stringa XHTML rappresentante il corpo della pagina
     * @see Compilable
     */
    function getContents()
    {
        $site = $this->site;
        $siteID = $site->getID();
        $homepage = $this->homepage;
        $categories = $site->getCategories();

        $contents = $homepage->getContents();
        $contents .= h1("Le notizie");
        //Aggiunge le notizie in prima pagina
        $news = $site->getNews();
        $newscount = 0;
        foreach ($news as $i) {
            //Massimo 5 notizie sulla homepage
            if ($newscount >= 5) {
                $contents .= h2(a(UserNews::staticGetFileName($this->site),
                    "Tutte le notizie..."));
                break;
            }
            $newscount++;
            $newsTitle = $i->getTitle();
            $newsID = $i->getID();
            $content = $i->getContents().br();
            $author = $i->getAuthor();
            $authorString = 
    
            $date = $i->getDate();
            $contents .= h2(b($newsTitle).br().$date,"notizia$newscount");
            
            //Aggiunge gli articoli correlati
            $correlati = $i->getCorrelatedArticles();
            $ncorrelati = $i->getCorrelatedArticlesCount();
            if ($ncorrelati>0) {
                $temp = "";
                foreach ($correlati as $correlato) {
                    $idCorrelato = $correlato->getID();
                    $titoloCorrelato = $correlato->getTitle();
                    $temp .= a(UserArticle::staticGetFileName($correlato),
                        $titoloCorrelato);
                    $ncorrelati--;
                    if ($ncorrelati >0) {
                        //Ci sono altri articoli, metto una virgola
                        $temp .= ", ";
                    }
                }
                $contents .= p("Articoli correlati a questa notizia: ".$temp);
            }
            //Aggiunge il corpo della notizia e la firma dell'autore
            $contents .= p($content).br().getAuthorSignature($author);
        }

        return $contents;
    }
    
    /**
     * Ritorna una stringa di parole chiave (solo testo, separate da virgole)
     * di questa pagina.
     *
     * @return string la stringa rappresentante le parole chiave della pagina
     * @see Compilable
     */
    function getKeywords()
    {
        return $this->homepage->getKeywords();
    }
        
    /**
     * Ritorna il nome del file in cui questa pagina deve essere salvata.
     *
     * @return string il nome del file
     * @see Savable
     */
    function getFileName()
    {
        return $this->staticGetFileName($this->site);
    }
    
    /**
     * Versione statica del metodo precedente: ritorna il nome del 
     * file in cui questa pagina deve essere salvata.
     *
     * @return string il nome del file
     * @see Savable
     */
    function staticGetFileName($site)
    {
        return "/index".$site->getID().".html";
    }
        
    /**
     * Ritorna il nome del file in cui questa pagina deve essere salvata
     * (versione precedente).
     *
     * @return string il nome del file
     * @see Savable
     */
    function getOldFileName()
    {
        return "index".$this->site->getID().".html";
    }
}
?>
