<?php
/* vim: set expandtab tabstop=4 shiftwidth=4: */
// +----------------------------------------------------------------------+
// | MCMS: a PHP Content Management System for creating accessible sites. |
// | Copyright (C) 2006  Silvio Moioli                                    |
// |                                                                      |
// | This program is free software; you can redistribute it and/or modify |
// | it under the terms of the GNU General Public License as published by |
// | the Free Software Foundation; either version 2 of the License, or    |
// | (at your option) any later version.                                  |
// |                                                                      |
// | This program is distributed in the hope that it will be useful,      |
// | but WITHOUT ANY WARRANTY; without even the implied warranty of       |
// | MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the        |
// | GNU General Public License for more details.                         |
// |                                                                      |
// | You should have received a copy of the GNU General Public License    |
// | along with this program; if not, write to the Free Software          |
// | Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307 |
// +----------------------------------------------------------------------+
// | Authors: Silvio Moioli <silvio at moioli dot net> www.moioli.net     |
// +----------------------------------------------------------------------+
//
//$Id:

require_once $_SERVER["DOCUMENT_ROOT"]."/admin/lib/view/UserPage.php";
require_once $_SERVER["DOCUMENT_ROOT"]."/admin/lib/view/Tagger.php";

/**
 * Rappresenta la mappa di navigazione di un sito.
 * 
 * @package  MCMS
 * @version  2
 * @author   Silvio Moioli <silvio at moioli dot net>
 */
class UserMap extends UserPage
{
    /** @var Homepage l'oggetto corrispondente alla home del sito */
    var $homepage = null;
          
    /**
     * Costruttore standard
     *
     * @param Site $site il sito a cui questa pagina appartiene
     * @see AdminPage
     */
    function UserMap($site)
    {
        parent::UserPage($site);
        $this->homepage=$site->getHomepage();
    }
    
    /**
     * Ritorna il titolo (in XHTML) di questa pagina.
     *
     * @return string una stringa XHTML rappresentante il titolo della pagina
     * @see Compilable
     */
    function getTitle()
    {
        return a(UserHomepage::staticGetFileName($this->site),
            $this->homepage->getTitle()." > Mappa del sito");
    }
    
    /**
     * Ritorna una breve descrizione (solo testo) di questa pagina.
     *
     * @return string una stringa rappresentante la descrizione della pagina
     * @see Compilable
     */
    function getDescription()
    {
        return "Mappa del sito ".$this->site->getShortURL();
    }
    
    /**
     * Ritorna un array di stringhe XHTML relative al menu (barra di navigazione)
     * di questa pagina.
     *
     * @return array vettore di stringhe XHTML rappresentante il menu della pagina
     * @see Compilable
     */
    function getMenuEntries()
    {
        return array(p("Torna alla ".a(
            UserHomepage::staticGetFileName($this->site),"homepage")));
    }
    
    /**
     * Ritorna il contenuto (XHTML) del corpo di questa pagina.
     *
     * @return string la stringa XHTML rappresentante il corpo della pagina
     * @see Compilable
     */
    function getContents()
    {
        $site = $this->site;
        $siteID = $site->getID();
        $homepage = $this->homepage;
        $categories = $site->getCategories();
                
        $contents = h2(a(
            UserHomepage::staticGetFileName($this->site),
            "Homepage"));
        $contents .= h2("Sezioni e articoli");
        foreach ($categories as $i) {
            $id = $i->getID();
            $name = $i->getName();
            $desc = $i->getDescription();
            if ($i->getArticlesCount()>0) {
                $contents .= h3(a(UserCategory::staticGetFileName($i),
                    $name)." - $desc");
                $articles = $i->getArticles();
                $listContents = array();
                foreach ($articles as $j) {
                    $articleID = $j->getID();
                    $articleTitle = $j->getTitle();
                    $listContents []= a(UserArticle::staticGetFileName($j),
                        $articleTitle);
                }
                $contents .= unorderedList($listContents);
            }
        }
        $contents .= h2("Notizie");
        $news = $site->getNews();
        $newscount = 0;
        $listContents = array();
        foreach ($news as $i) {
            $newsID = $i->getID();
            $listContents []= a(UserNews::staticGetFileName($this->site)
                ."#notizia$newsID", $i->getTitle());
        }
        $contents .= unorderedList($listContents);

        return $contents;
    }
    
    /**
     * Ritorna una stringa di parole chiave (solo testo, separate da virgole)
     * di questa pagina.
     *
     * @return string la stringa rappresentante le parole chiave della pagina
     * @see Compilable
     */
    function getKeywords()
    {
        return "";
    }
    
    /**
     * Ritorna il nome del file in cui questa pagina deve essere salvata.
     *
     * @return string il nome del file
     * @see Savable
     */
    function getFileName()
    {
        return $this->staticGetFileName($this->site);
    }
    
    /**
     * Versione statica del metodo precedente: ritorna il nome del 
     * file in cui questa pagina deve essere salvata.
     *
     * @return string il nome del file
     * @see Savable
     */
    function staticGetFileName($site)
    {
        return "/mappa___".$site->getID().".html";
    }
        
    /**
     * Ritorna il nome del file in cui questa pagina deve essere salvata
     * (versione precedente).
     *
     * @return string il nome del file
     * @see Savable
     */
    function getOldFileName()
    {
        return "map".$this->site->getID().".html";
    }

}
?>
