<?php
/* vim: set expandtab tabstop=4 shiftwidth=4: */
// +----------------------------------------------------------------------+
// | MCMS: a PHP Content Management System for creating accessible sites. |
// | Copyright (C) 2006  Silvio Moioli                                    |
// |                                                                      |
// | This program is free software; you can redistribute it and/or modify |
// | it under the terms of the GNU General Public License as published by |
// | the Free Software Foundation; either version 2 of the License, or    |
// | (at your option) any later version.                                  |
// |                                                                      |
// | This program is distributed in the hope that it will be useful,      |
// | but WITHOUT ANY WARRANTY; without even the implied warranty of       |
// | MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the        |
// | GNU General Public License for more details.                         |
// |                                                                      |
// | You should have received a copy of the GNU General Public License    |
// | along with this program; if not, write to the Free Software          |
// | Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307 |
// +----------------------------------------------------------------------+
// | Authors: Silvio Moioli <silvio at moioli dot net> www.moioli.net     |
// +----------------------------------------------------------------------+
//
//$Id:

require_once $_SERVER["DOCUMENT_ROOT"]."/admin/lib/view/Savable.php";
require_once $_SERVER["DOCUMENT_ROOT"]."/admin/lib/view/Tagger.php";

/**
 * Classe astratta che rappresenta una pagina del sito creato.
 * Pu essere salvata su un file (implementa Savable) e i plugin
 * (sottoclassi di Component) possono esservi applicati.
 * 
 */
/*abstract*/ class UserPage extends Savable
{
    /** @var Site il sito a cui questa pagina appartiene */
    var $site = null;
    /** @var string i caratteri ammessi nel nome di un file */
    var $allowedFileChars = 
        'ABCDEFGHIJKLMNOPQRSTUVWXYZabcdefghijklmnopqrstuvwxyz0123456789_';
    
    /**
     * Costruttore di default
     *
     * @param Site $site il sito a cui questa pagina appartiene
     */
    function UserPage($site)
    {
        parent::Compilable();
        $this->site=$site;
    }
    
    /**
     * Ritorna il sito a cui questa pagina appartiene.
     *
     * @return Site il sito a cui questa pagina appartiene.
     */
    function getSite()
    {
        return $this->site;
    }
     
    /**
     * Le pagine di finali usano un template unico.
     *
     * @return string il nome del file del template
     */
    function getTemplate()
    {
        return "userTemplate.tpl";
    }
    
    /**
     * I plugin vengono applicati indistintamente a tutte le pagine del sito finale.
     *
     * @return un array di Components
     * @see Compilable
     */
    function getComponents()
    {
        return $this->site->getComponents();
    }

    /**
     * Ritorna una stringa con i soli caratteri ammessi in un nome di file.
     */
    function fileName($fullName){
        $result = '';
        for($i=0; $i<strlen($fullName);$i++){
            if(strpos($this->allowedFileChars,$fullName[$i])===false){
                $result .='_';
            }
            else{
                $result .=$fullName[$i];
            }
        }
        return $result;
    }
}
?>
